#
# spec file for package gnome-software
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gs_plugin_api 22
%bcond_with profiling

Name:           gnome-software
Version:        48.1
Release:        1.1
Summary:        GNOME Software Store
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Software
Source0:        %{name}-%{version}.tar.zst
%if 0%{?sle_version}
# PATCH-FIX-OPENSUSE gnome-software-launch-gpk-update-viewer-for-updates.patch bsc#1077332 boo#1090042 sckang@suse.com -- Don't launch gnome-software when clicking the updates notification. Launch gpk-update-viewer instead.
Patch0:         gnome-software-launch-gpk-update-viewer-for-updates.patch
# PATCH-FIX-OPENSUSE gnome-software-disable-offline-update.patch bsc#944832 sckang@suse.com -- Disable offline update in SLE and openSUSE Leap
Patch1:         gnome-software-disable-offline-update.patch
%endif
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  suse-xsl-stylesheets
BuildRequires:  pkgconfig(appstream) >= 0.14.0
BuildRequires:  pkgconfig(flatpak) >= 0.6.12
BuildRequires:  pkgconfig(fwupd) >= 1.0.3
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.11.5
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.18.0
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.2.0
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libhandy-1) >= 1.2.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(malcontent-0) >= 0.5.0
BuildRequires:  pkgconfig(ostree-1)
BuildRequires:  pkgconfig(packagekit-glib2) >= 1.1.0
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xmlb) >= 0.1.7
%if %{with profiling}
BuildRequires:  pkgconfig(sysprof-capture-4)
%endif
# boo#1090042
Requires:       fwupd
Requires:       iso-codes
Recommends:     %{name}-plugin-packagekit
Recommends:     flatpak
# bsc#1178768
%if 0%{?sle_version}
Recommends:     gnome-packagekit
%endif

%description
AppStore like management of Applications for your GNOME Desktop.

%package devel
Summary:        Development files for the GNOME software store
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
This subpackage contains the header files for developing
GNOME software store plugins.

%package plugin-packagekit
Summary:        GNOME Software Store - PackageKit plugin
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       PackageKit
Requires:       (libzypp-plugin-appdata if PackageKit-backend-zypp)

%description plugin-packagekit
This subpackage provides the packagekit plugin used by
the GNOME software store.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D tests=false \
	-D malcontent=true \
	-D sysprof=%{?with_profiling:enabled}%{!?with_profiling:disabled} \
	-D opensuse-distro-upgrade=true \
	-D hardcoded_curated=true \
	-D default_featured_apps=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

# Remove any piece of doc that ends up in non-standard locations and use the doc macro instead
rm %{buildroot}%{_datadir}/doc/%{name}/README.md
%if !0%{?sle_version} || 0%{?sle_version} >= 160000
# Move autostart file to /usr/etc
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
mv %{buildroot}%{_sysconfdir}/xdg/autostart/org.gnome.Software.desktop %{buildroot}%{_distconfdir}/xdg/autostart/org.gnome.Software.desktop
%endif

cat >> %{buildroot}%{_datadir}/glib-2.0/schemas/20_org.gnome.software-opensuse.gschema.override << FOE
[org.gnome.software]
official-repos = [ 'repo-oss', 'repo-update', 'repo-non-oss', 'download.opensuse.org-oss', 'download.opensuse.org-tumbleweed', 'download.opensuse.org-non-oss' ]
FOE

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/%{name}
%{_datadir}/metainfo/org.gnome.Software.Plugin.Epiphany.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Flatpak.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.Plugin.Fwupd.metainfo.xml
%{_datadir}/metainfo/org.gnome.Software.metainfo.xml
%{_datadir}/applications/gnome-software-local-file-flatpak.desktop
%{_datadir}/applications/gnome-software-local-file-fwupd.desktop
%{_datadir}/applications/gnome-software-local-file-packagekit.desktop
%{_datadir}/applications/org.gnome.Software.desktop
%{_datadir}/bash-completion/completions/gnome-software
%{_datadir}/dbus-1/services/org.gnome.Software.service
%{_datadir}/dbus-1/services/org.freedesktop.PackageKit.service
%{_datadir}/glib-2.0/schemas/org.gnome.software.gschema.xml
%{_datadir}/glib-2.0/schemas/20_org.gnome.software-opensuse.gschema.override
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Software-search-provider.ini
%{_datadir}/icons/hicolor/*/*/*.svg
%dir %{_libdir}/gnome-software
%{_libexecdir}/gnome-software-cmd
%{_libexecdir}/gnome-software-restarter
%{_mandir}/man1/%{name}.1%{?ext_man}
%if !0%{?sle_version} || 0%{?sle_version} >= 160000
%{_distconfdir}/xdg/autostart/org.gnome.Software.desktop
%else
%{_sysconfdir}/xdg/autostart/org.gnome.Software.desktop
%endif

%dir %{_libdir}/gnome-software/plugins-%{gs_plugin_api}/
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_dpkg.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_dummy.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_epiphany.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_fedora-langpacks.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_fedora-pkgdb-collections.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_flatpak.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_fwupd.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_generic-updates.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_hardcoded-blocklist.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_icons.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_malcontent.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_modalias.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_os-release.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_opensuse-distro-upgrade.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_provenance-license.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_provenance.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_repos.so
%{_libdir}/gnome-software/libgnomesoftware.so.%{gs_plugin_api}
%dir %{_datadir}/swcatalog/
%dir %{_datadir}/swcatalog/xml/
%{_datadir}/swcatalog/xml/gnome-pwa-list-foss.xml
%{_datadir}/swcatalog/xml/gnome-pwa-list-proprietary.xml
%{_datadir}/swcatalog/xml/org.gnome.Software.Curated.xml
%{_datadir}/swcatalog/xml/org.gnome.Software.Featured.xml

%files devel
%doc AUTHORS
%dir %{_includedir}/%{name}
%{_datadir}/gtk-doc/html/%{name}/
%dir %{_datadir}/doc/gnome-software
%{_includedir}/%{name}/*.h
%{_libdir}/pkgconfig/gnome-software.pc
%{_libdir}/gnome-software/libgnomesoftware.so

%files plugin-packagekit
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_packagekit.so
%{_libdir}/gnome-software/plugins-%{gs_plugin_api}/libgs_plugin_appstream.so

%files lang -f %{name}.lang

%changelog
* Thu Apr 10 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.1:
  + Improve contrast of some app safety ratings in dark mode
  + Improve error handling when fetching app reviews
  + Updated translations.
* Fri Mar 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Correctly show update detail text not provided in markdown.
  + Updated translations.
* Fri Feb 28 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + Minor interface improvements on the updates page
  + Various minor performance improvements
  + Improve error handling for app launches and distribution
    upgrades
  + Fix a crash on the app review dialog
  + Fix version checks preventing some firmware updates when
    historical updates are also listed
  + Fix a crash when copying error details
  + Minor interface improvements to search
  + Improvements to flatpak permissions checking for D-Bus
  + Updated translations.
* Fri Jan 31 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Support installing flatpaks via a flatpak+https: link.
  + Fix notifying about outdated updates when in power saver mode
    or offline.
  + Prioritise verified apps in source list.
  + Updated translations.
* Tue Jan 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.alpha:
  + Fix downloads of firmware updates
  + Fix the release process
  + Updated translations.
- Stop passing soup2=false to meson setup, no longer recognized nor
  needed.
- Bump gs_plugin_api to 22 following upstream changes.
* Tue Jan 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.4:
  + Fix downloads of firmware updates
  + Fix the release process
* Sat Jan  4 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.3:
  + Fix a crash when cancelling an offline update.
  + Updated translations.
* Mon Nov 25 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Fix distro upgrade when certain version of PackageKit is used
  + Fix a crash when uninstalling a Snap app
  + Make uninstall dialog adaptive for small screens
  + Prefer Appstream data from swcatalog instead of app-info
    directories
  + Updated translations.
* Thu Oct 10 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Fix crash in snap plugin when launching apps
  + Fix display of versions for packages being installed as part of
    an update
  + Various minor improvements to the review submission dialog
  + Fix a crash in the DKMS plugin
  + Updated translations.
* Fri Sep 27 2024 bjorn.lie@gmail.com
- Update to version 47.0+23:
  * gs-details-page: Don't override the "page_failed" AdwStatusPage
    title
  * Add initial Indonesian translation of help
  * plugins: appstream: make refine found flag local to app loop
  * plugins: appstream: abort refine_from_id if there are no
    components
  * plugins: appstream: fix comment
  * plugins: don't make core plugins depend on non-core ones
  * Updated translations.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Pass hardcoded_curated=true and Ddefault_featured_apps=true to
  meson configure until we decide if we should ship our own or not.
* Sun Sep 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Do not install example featured software lists by default.
  + Updated translations.
* Sat Sep 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Update help pages and add some translations of them
  + Correct tooltips of review voting buttons
  + Lower power consumption when certain pages are not visible
  + Updated translations.
* Fri Sep 13 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Shorten text in some notifications
  + Fix Orca not reading the contents in Preferences dialog
  + Enhance behavior of a review row
  + Added plugin to ease installation of DKMS and akmods key with
    enabled Secure Boot
  + Updated translations.
- Changes from version 47.alpha:
  + Fix a crash when updating apps when built with Mogwai
  + Fix a crash when installing flatpak application
  + Correct desktop/mobile hardware support detection
  + Correct state of Fedora upgrade
  + Several fixes in historical updates for rpm-ostree
  + Fix a crash when no appstream data is found
  + Correct app safety calculation
  + Correct Flatpak system and user apps recognition
  + Slightly speed-up rpm-ostree metadata refresh
  + Show "Install All" button only for codecs
  + Prefer vendor name from os release in app origin
  + Make more jobs asynchronous
  + Port to recent Adwaita widgets
  + Updated translations.
- Add itstool BuildRequires: New dependency.
- Bump gs_plugin_api define to 21 following upstream changes.
* Thu Sep 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.5:
  + Reduce power usage when the main window is closed.
  + Updated translations.
* Sun Aug 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.4:
  + Correct broken formatting when using <code> in AppStream
    metadata
  + Updated translations.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.3:
  + Show "Install All" button only for codecs
  + Prefer vendor name from os release in app origin
  + Updated translations.
* Fri May 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Fix a crash when no appstream data is found.
  + Correct app safety calculation.
  + Correct Flatpak system and user apps recognition.
  + Slightly speed-up rpm-ostree metadata refresh.
  + Updated translations.
* Thu May  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Fix a crash when updating apps when built with Mogwai.
  + Fix a crash when installing flatpak application.
  + Correct desktop/mobile hardware support detection.
  + Correct state of Fedora upgrade.
  + Several fixes in historical updates for rpm-ostree.
  + Updated translations.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Improvements for screen readers.
  + Stop ‘loading updates’ in a loop on Debian.
  + Updated translations.
* Fri Mar  1 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Various UI text improvements.
  + Fix launch of some apps.
  + Fix invalid app state after it's uninstalled.
  + Fix read of app description text.
  + Do not ask to reboot after failed firmware update.
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Show feedback for all conditions that pause automatic updates.
  + Various UI improvements and move to new libadwaita widgets.
  + Fix loading OS AppStream catalog data if it is available as
    YAML.
  + Add openSUSE Leap distro upgrade plugin.
- Pass -D opensuse-distro-upgrade=true to meson: we are openSUSE,
  so we want the plugin.
- Drop gnome-software-plugin-opensuse-distro-upgrade.patch: fixed
  upstream.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Recognize links in package update descriptions.
  + Expose package names discreetly in the UI.
  + Increase speed of load of the category pages.
  + Improve search match with multiple words.
  + Recognize verified apps by Flathub.
  + Correct message when installing firmware updates.
  + Improve application safety checks.
  + Improve update preferences dialog.
  + Fix deadlock when cancelling app update.
  + Support user installation of local flatpak files.
  * Fix apps appearing unsorted and without tiles in category page.
- Convert to source service for easier updating.
- Drop gnome-software-support-appstream-1_0.patch: fixed upstream.
* Thu Dec 28 2023 Yifan Jiang <yfjiang@suse.com>
- Do not use _distconfdir on SLE/Leap less than version 16.
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Add gnome-software-support-appstream-1_0.patch to
  support building with appstream 1.0 (boo#1217047)
* Fri Dec  1 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.2:
  + Updated translations.
* Fri Oct 27 2023 Jonathan Kang <jonathankang@gnome.org>
- Rebase gnome-software-disable-offline-update.patch(bsc#1216603).
* Fri Oct 27 2023 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-software-plugin-opensuse-distro-upgrade.patch: plugins:
  add opensuse-distro-upgrade plugin(glgo#GNOME/gnome-software!1557).
* Fri Oct 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Various styling fixes
  + Report PackageKit GPG-related errors in the GUI
  + Flatpak permission checks improvements
  + Optimize loading of the details page
  + Updated translations.
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Fix a crash when downloading resources from the Internet
  + Fix a crash after cancelled Restart request
  + Correct safety rating for KDE apps
  + Correct version history widgets visibility in the details page
  + Updated translations.
* Mon Sep  4 2023 Luciano Santos <luc14n0@opensuse.org>
- Add with(out) "profiling" build switch and disable it, by
  default, as profiling isn't meant for general use. This nests
  pkgconfig(sysprof-capture-4) BuildRequires under an if-with
  expression and passes profiler=(enabled|disabled) to meson,
  depending on the profiling switch.
* Sat Sep  2 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.rc:
  + Fix firmware's 'Restart & Update' to ask for the restart.
  + Fix app getting unresponsive when loading screenshots.
  + Improve performance for PackageKit plugin search-by-file.
  + Improve app license display.
  + Improve search to also check for 'contains' words.
  + Various minor styling updates.
  + Updated translations.
- Drop deprecated pkgconfig(sysprof-4) BuildRequires and pinpoint
  pkgconfig(sysprof-capture-4) BuildRequires to 45.rc, as a
  minimum.
* Fri Aug  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Improve error notifications from failed GPG checks
  + Disable animations in the UI according to the user’s
    accessibility settings
  + Fix applying updates which require some packages to be removed
    to satisfy dependencies
  + Stop using the software repositories dialog provided by the
    distribution, and always use GNOME Software’s inbuilt dialog;
    this will affect Debian and Ubuntu
  + Updated translations.
* Fri Aug  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Indicate when OS updates includes security fixes
  + Ask whether to clear app storage for Flatpak apps on uninstall
  + Show a notification when system updates are downloaded
  + Advertise if an installed Flatpak app has reached end of life
  + Revamp Safety ratings
  + Fix slow Repositories dialog open
  + Fix card view and key navigation in the Explore page
  + Fix a crash on startup in GNOME OS
  + Fix navigation between "Other Apps by Developer" in the Details
    page
  + Fix a crash when refining a Flatpak app
  + Fix a state recover after a failed app update
  + Updated translations.
* Fri Aug  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.4:
  + Improve error notifications from failed GPG checks.
  + Disable animations in the UI according to the user’s
    accessibility settings.
  + Fix applying updates which require some packages to be removed
    to satisfy dependencies.
  + Updated translations.
* Fri Jun 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.3:
  + Fix a crash when refining a flatpak app.
  + Fix a state recover after a failed app update.
  + Updated translations.
* Fri May 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Fix subsequent checking for updates if the first check after
    login fails.
  + Fix checking for updates when automatic updates are disabled.
  + Fix rare stall when many background jobs are running.
  + Don’t download rpm-ostree updates when only checking if updates
    are available.
  + Fix bug with listing flatpak addons when multiple flathub
    remotes are enabled.
  + Fix duplicated sources in app details page when using an
    appstream URL.
  + Reduce background resource consumption when idle.
  + Updated translations.
* Fri Apr 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Fix firmware updates state change after update.
  + Fix origin reference information for PackageKit apps.
  + Fix a crash after dismissing firmware update warning dialog.
  + Fix a crash on repo removal.
  + Updated translations.
* Thu Mar 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Fix missing separators in system updates dialog.
  + Updated translations.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Fix a crash during install of a firmware update.
  + Fix notifications of a prepared update.
  + Fix cancellation of an update.
  + Update details page on app job start/end.
  + Fix a crash after cancelling of a single package update.
  + Updated translations.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Add a preference for only showing freely-licensed apps
  + Improve design of Install/Uninstall buttons for app addons
  + Fix loading flatpak bundles if a runtime is missing
  + Improvements to the UI for ratings and reviews
  + Fix refreshing the details page after searching for an app
  + Improve choice of icons for apps where a themed icon is
    available
  + Improve performance of downloading remote icons significantly
  + Updated translations.
- Changes from version 44.alpha:
  + Allow automatically removing unneeded runtimes
  + Show changelogs for rpm-ostree updates
  + Limit the maximum description length in context tiles
  + Support a less-prominent UI for regular updates for image-based
    OSs
  + Improvements to error notification display
  + Reduce reloading/refreshing of view when installing apps
  + Minor usability improvements to review lists and adding a
    review
  + Stop using libdnf in rpm-ostree backend
  + UI polish on app source chooser
  + Fix distro upgrades
  + Fix system-wide external AppStream support
  + UI polish on Incompatible Software dialog
  + Fix opening web apps
  + Fix notifying about available firmware updates
  + Improve scaling of Explore page on phones
  + Add a placeholder to search entry
  + Fix repo authentication dialog
  + Periodically refresh cached app icons
  + Improve labels and tooltips on Updates page
  + Annotate firmware updates with their release urgency
  + Adapt to GTK API deprecations
  + Use the OS logo for minor update rows for image-based OSs
  + Change ‘application’ to ‘app’ in translatable strings
  + Stop notifying about unprepared critical updates
  + Show the ‘Learn More’ link for larger updates of image-based
    OSs if provided
  + Add translations for more firmware device categories
  + Updated translations.
- Bump gs_plugin_api define to 20 following upstream changes.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.5:
  + Fix few memory leaks.
- Drop patches fixed upstream:
  + 66b400d63b8d7b921b83250a8b9a09e9a1eb6732.patch
  + 1355554764815195aaf9f6e23acdd7a9c521ceaa.patch
* Mon Feb 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream leak fixes:
  + 66b400d63b8d7b921b83250a8b9a09e9a1eb6732.patch:
    gs-plugin-job-list-apps: Fix a leak of the GsAppQuery
  + 1355554764815195aaf9f6e23acdd7a9c521ceaa.patch:
    gs-plugin-job-manage-repository: Fix a minor leak
* Fri Feb 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.4:
  + Stop cancelled search in appstream data early.
  + Lookup for appstream-provided icons in more directories.
* Mon Jan 16 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Also add download.opensuse.org-non-oss (NON-OSS repo)
  download.opensuse.org-oss (OSS repo), and
  download.opensuse.org-tumbleweed (Update repo) to
  software-opensuse.gschema.override, declaring them also
  official repositories (the names match the ones picked by the NET
  installer).
* Fri Jan  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.3:
  + Periodically expire cached app icons.
  + Stop notifying about unprepared critical updates.
  + Updated translations.
* Sat Dec  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Fix show of updatable app in the details page.
  + Fix search for apps providing some feature under rpm-ostree.
  + Fix sending of ODRS data when using libsoup3.
  + Fix occasional crash when installing apps.
  + Updated translations.
* Wed Oct 26 2022 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-software-disable-offline-update.patch: Disable offline
  update in SLE and openSUSE Leap(bsc#944832).
* Fri Oct 21 2022 Richard Brown <rbrown@suse.com>
- Split out packagekit (and related appstream) plugins into a
  plugin-packagekit package. Recommend it by default,
  and shift the hard requirement for PackageKit (and appstream if zypp)
  to the new subpackage
- This will allow flatpak-only use of gnome-software, as needed by
  the MicroOS Desktop
* Fri Oct 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Fix searches not completing if installing or uninstalling an
    app at the same time.
  + Notify of errors when running a flatpak app whose runtime is
    missing.
  + Fix installing local RPM packages.
  + Fix distribution upgrades when package conflicts are present.
  + Fix opening web apps from their details page.
  + Improve appearance of app ratings if ratings data cannot be
    downloaded.
  + Fix crash when showing offline update errors on startup.
  + Highlight priority of firmware updates, making security fixes
    more obvious.
  + Fix installation of pending apps in some situations.
  + Fix downloading of rpm-ostree app updates from the Updates
    page.
  + Updated translations.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Tue Sep 13 2022 Callum Farmer <gmbr3@opensuse.org>
- Install gschema override with distribution default priority of
  20
* Fri Sep  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Supports video as a screenshot.
  + Improvements of source picker in the details page.
  + Fixes a bug when viewing details of a package file.
  + Fixes a bug when reading certain .flatpakref file.
  + Updated translations.
- Drop 81301904.patch: Applied upstream.
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Now that flatpak is switched to use soup3, we can drop
  pkgconfig(libsoup-2.4) and enable pkgconfig(libsoup-3.0)
  BuildRequires, and pass soup2=false to meson.
- Add 81301904.patch: Remove apicheck of flatpak soupapi, patch
  needed until next gnome-software release.
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Various fixes related to changed threading model.
  + Various UI parts updated.
  + Sources dropdown had been reworked.
  + Fixes a rare crash when showing app details.
  + Updated translations.
* Fri Aug  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.alpha:
  + Various improvements to notifications.
  + Fix several crashes when handling flatpak apps.
  + Add ‘Other Apps by Author’ section in the app details page.
  + Improve styling of app context lozenges.
  + Add ‘Available for Distro’ section to the overview page
  + Show more details about file system permissions requested by
    flatpak apps.
  + Show more types of URI from app metainfo.
  + Fix a few issues when using a dark mode theme.
  + Fix some issues with arrows in right-to-left locales.
  + Fix language pack installation for certain locales.
  + Improve debug output to make user bug reports more useful.
  + Add `--uninstall=ID` command line option.
  + Allow scrolling screenshots by clicking on next and previous
    screenshots.
  + Add support for webapps.
  + Allow swiping back in the shell using touch gestures.
  + Improved caching of downloaded metadata.
  + Many internal architectural changes to make the code more
    maintainable.
  + The popular-overrides GSettings key has been removed.
  + The hardcoded_popular Meson option has been renamed to
    hardcoded_curated.
- Bump gs_plugin_api to 19.
- Drop -D valgrind=false meson paramters: no longer understood.
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.4:
  + Fix update detail text, when it contains markup.
  + Updated translations.
* Thu Jun 30 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.3:
  + Fix some crashes when handling flatpaks.
  + Fix incorrectly showing a restart notification after a failed
    firmware update.
  + Fix a mismatch between app review ratings at the top and bottom
    of the page.
  + Fix prompt dialogs when updating firmware on devices which need
    user interaction.
  + Updated translations.
* Thu Jun 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Ship software-opensuse.gschema.override, declaring the
  repositories 'repo-oss', 'repo-update', and 'repo-non-oss' as the
  official repositories (boo#1189907).
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Fix installing langpacks for certain locales.
  + Improve UI presentation of flatpak apps with complex
    permissions.
  + Fix minor UI glitches on updates page.
  + Fix installation of .deb packages with PackageKit ≥ 1.2.5.
  + Fix the ‘Remove’ button for your own app reviews.
  + Minor UI fixes when using a dark theme.
  + Updated translations.
* Fri Apr 29 2022 Emily Gonyer <emilyyrose@gmail.com>
- Updated to version 42.1:
  + #1514 GNOME OS: Most system apps have no icons in installed
    list.
  + #1690 Button to go back is missing in "OS Updates" page opened
    from "Installed Updates" window.
  + #1693 Fix an issue where Software would sometimes display a
    "Software Updates Failed" error message on startup.
  + #1712 Clicking "Fedora Flathub Selection" does not update the
    filtered Flathub AppStream metadata until reboot.
  + #1723 Installed Updates dialog UI papercuts.
  + #1727 Wrong direction of arrows in updates list in RTL
    languages.
  + !794 flatpak: Prefer to install runtimes from the same remote
    as the application.
  + !1235 Find AppStream metadata in every possible location.
  + !1299 Avoid re-downloads of not-yet-stale data in some cases.
  + !1307 Change thread I/O priority depending on job priority.
  + !1313 Ensure labels don't overlap in app lists.
  + !1318 Fix an issue preventing the user from disabling some
    repositories on Fedora.
  + Translation updates.
- Drop 8cbce25.patch - patched upstream, #1693.
* Fri Apr  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add 8cbce25.patch: Fix Gnome-Software keep poping up notification
  "Software updates failed".
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Various fixes related to changed threading model.
  + Added several appstream-related fixes.
  + Updated translations.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Cancel ongoing update downloads when system power is low
  + Numerous small user interface fixes and tweaks
  + Prioritize full matches in search results
  + Improvements in dark mode
  + Fix disabling flatpak remotes from the ‘Software Repositories’
    dialog
  + Threading and performance improvements which should reduce the
    number of user interface freezes
  + Update some icons
  + Check for updates when moving from a metered to a non-metered
    network connection
  + Updated translations.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Allow --verbose to be enabled at runtime
  + Condense the rows in the age rating context dialog
  + Update the UI for ratings and reviews of apps
  + Improve the appearance of the category page loading screen
  + Drop the first run dialog
  + Improvements to dark theming
  + Support viewing a specific metainfo file using --show-metainfo
  + Several more threading improvements
  + Icon updates
  + Drop the hardcoded-popular plugin in favour of an appstream
    file
  + The background image for upgrades is now looked for using
    several well-known (and distribution-specific) names in
    ${DATADIR}/gnome-software/backgrounds, and the previous
    Fedora-specific default background image is no longer
    distributed. Similarly, the upgrade-background-uri GSettings
    key has been removed. Distributions may need to update how they
    ship background images. See doc/vendor-customisation.md.
  + Updated translations.
- Move autostart .desktop to distconfdir.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Various UI parts updated
  + Support more markup in the application description
  + Ask about package signature with PackageKit on signing issue
  + Show better System Update progress
- Drop gnome-software-flatpak-refresh-no-interaction.patch: Fixed
  upstream.
- Add pkgconfig(gtk4) and  pkgconfig(libadwaita-1) BuildRequires
  following upstream changes.
- Drop pkgconfig(gtk-3.0) BuildRequires following upstream changes.
- Add disabled pkgconfig(libsoup-3.0) BuildRequires: We can not yet
  enable this, as our flatpak is still built with libsoup-2.4.
  Following this, pass soup2=true to meson to force the use of old
  libsoup.
- Bump gs_plugin_api define to 17 following upstream changes.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.5:
  + Disable scroll-by-mouse-wheel on featured carousel.
  + Ensure details page shows app provided on command line.
  + Added several appstream-related fixes.
  + Updated translations.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.4:
  + Updated translations.
* Fri Jan  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.3:
  + Remove various cultural sensitivity badges.
* Fri Dec 24 2021 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-software-flatpak-refresh-no-interaction.patch: flatpak:
  Set no-interaction correctly when refreshing(bsc#1123722,
  glgo#GNOME/gnome-software!1145).
* Fri Dec  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Fix a crash when processing age ratings
  + Reload application details only when not installing/removing
    the application
  + Do not follow symlinks when calculating disk size usage
  + Fix addons section, which could show addons for different
    application
  + Updated translations.
* Thu Oct 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Fix showing a ‘transaction in progress’ error when using the
    rpm-ostree plugin
  + Don’t recommend a reboot if firmware updates fail
  + Fix flathub repo being considered present on Fedora 35 with
    filtered flathub
  + Allow searching for extensions
  + Fix translation of main button on updates page
  + Fix codec installation process
  + Various minor UI tweaks and fixes
  + Add new GNOME Circle apps to the featured carousel
  + Improve metadata support for snaps
  + Fix update checks being missed across suspend/hibernation
  + Ensure application lists are updated when repositories are
    enabled/installed or disabled/removed
  + Updated translations.
- Drop now unused _version 40_0 define.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Instead of showing all package-based apps as "potentially
    unsafe", only use that language for 3rd party ones.
  + Fix a bug where the "Show more" button on an app details page
    would flicker when the window is resized.
  + Fix a bug where Software sometimes shows an Uninstall button
    after uninstalling something.
  + Add GNOME Circle apps to the featured carousel.
  + Fix a bug where Software would sometimes fail to execute an
    install/remove operation for PackageKit software rather than
    showing a PolicyKit password prompt.
  + Fix a bug where Software would fail to upgrade the distribution
    via PackageKit.
  + Fix the hiding of rows on the Updates tab after they have been
    updated.
  + Updated translations.
* Wed Sep  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Tweaks to the context tiles and dialogs.
  + Fixes to the details page for non-desktop apps.
  + Re-add support for the add-ons categories.
  + Sort new and updated apps by release date on the category page.
  + Updated translations.
* Tue Aug 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Many parts of the user interface reworked.
  + Fix when the 'Launch' button is shown after an application
    install.
  + Fix appstream:// URL handling.
  + Fix application freeze on Flatpak application
    install/remove/update.
  + Disable automatic update downloads when in power saver mode.
  + Updated translations.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + Many parts of the user interface reworked.
  + Improve error reporting from flatpak when low on disk space.
  + Fix issues with updating the UI when uninstalling apps with
    add-ons.
  + Don’t keep rpm-ostreed alive forever.
  + Prevent polkit checks showing up for background operations.
  + Disallow submitting reviews for an app you haven’t installed.
  + Show download size in the Updates page.
  + Notify when restart is needed when uninstalling an app.
  + Fix some issues with searches not running.
  + Allow non-integer average star ratings for apps.
  + Reduce number of categories in the UI.
  + Improve ‘pending updates’ notifications.
  + Refine presentation of download and installed size on details
    page.
  + Remove left over gnome-online-account dependencies.
  + Updated translations.
- Drop pkgconfig(goa-1.0) BuildRequires: no longer needed.
- Drop gnome-software-no-static-lib.patch: Fixed upstream.
* Fri Aug 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.4:
  + flatpak: Improve search of applications.
  + Correct download size for app's runtime.
  + Updated translations.
* Sat Jul 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.3:
  + Fix a bug where app sources appeared in the header of the
    Updates tab.
  + Automatically install application updates, depending on the
    type of application and user config.
  + Avoid extra vertical space in the featured apps carousel.
  + Include apps from disabled repos in Shell Overview search
    results.
  + Distinguish between download size and installed size for
    PackageKit apps.
  + Properly update the "Last checked" timestamp on the Updates
    tab.
  + Fix a crash that sometimes happens when clicking on the Website
    button on a details page.
  + Fix a bug where the list of sources for an application was
    sometimes incomplete.
  + Updated translations.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Avoid spurious polkit prompts by the PackageKit plugin for
    background operations
  + Handle NULL OS name or version
  + Fix a crash related to version history gathering
  + Fix a crash when a Flatpak component had been renamed
  + Improve error reporting when low on disk space for Flatpak
  + Fix a deadlock after Flatpak changes from the command line
  + Fix list of alternative application sources to not show
    duplicates
  + Fix application icon loading for already cached icons
  + Fix crash loading empty DEP-11 data
  + Fix update of related Flatpak runtimes
  + Fix automatic download of pending updates
  + Consider only critical updates as important
  + Updated translations.
* Sun May  2 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.1:
  + Fix flatpak update state if update was already done outside of
    GNOME Software.
  + Update app state after repository is enabled or disabled.
  + Fix the overview opening empty in some situations.
  + Show apps which are being updated in the updates page, rather
    than just ones which are ready to be updated.
  + Fix section headers on ‘Installed’ page.
  + Fix searches not being triggered by typing in the search entry
    in some situations.
  + Fix duplicate origins being listed incorrectly in the app
    details page (in particular, for UngoogledChromium).
  + Fix a broken rpm-ostree repository causing other repositories
    to be ignored.
  + Fix animation glitch on featured apps carousel when going from
    app 2 to app 1.
  + Improve featured apps carousel contrast for Steam.
  + Speed up search queries by over 40%%.
  + Do not keep the rpm-ostree service alive forever while GNOME
    Software is running.
  + Fix broken header bar on application details page in some
    situations.
  + Prevent uninstallation of add-ons for system apps.
  + Fix search from Nautilus on Fedora Silverblue.
  + Fix reporting state of layered packages on Fedora Silverblue.
  + Fix updating add-on state when uninstalling an app.
  + Updated translations.
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update gnome-software-no-static-lib.patch in line with upstream
  suggestions: rename the private library from
  libgnomesoftware-40.0.so to libgnomesoftware-16.so; This is in
  line with the directpry name the plugins, linked to that version,
  are being installed to.
- Fold libgnomesoftware-40_0 into gnome-software:
  libgnomesoftware.so is a private library and serves no purpose
  without gnome-software.
* Sat Mar 20 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.0:
  + Fix handling of invalid or incomplete application icons.
  + Fix the plugin documentation to reflect reality.
  + Fix the Snap plugin to actually load icons.
  + Set download size to 0 after the package is downloaded.
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Implement new featured apps carousel.
  + List of Flatpak repositories is updated when changed using the
    Flatpak command line tool.
  + The loading page now shows the full color icon instead of the
    symbolic one.
  + Show release date in version history for releases that use the
    'date' attribute.
  + Improved icon handling, including with hiDPI screens.
  + Fixed a bug in remembering when update notifications were
    shown.
  + Build as a dynamic rather than a static library, and rearrange
    installation paths.
  + Updated translations.
- Bump gs_plugin_api from 14 to 16, following upstream.
- Rebase gnome-software-no-static-lib.patch.
* Wed Feb 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + GNOME Software now uses libappstream instead of
    libappstream-glib to work with appstream data which provides
    information about apps and other components.
  * App details pages show version history information when it's
    available.
  * The loading page now shows the full color icon instead of the
    symbolic one.
  * UI elements for displaying app add-ons have been tweaked to
    more closely match the designs.
  * Installed icons and the badge showing the number of updates
    available were changed back to blue from green.
  * The dropdown showing the available sources of an application
    includes the packaging format (e.g. Flatpak vs RPM).
  * A bug was fixed that prevented installation of .flatpakref
    files
  + Updated translations.
- Replace pkgconfig(appstream-glib) BuildRequires with
  pkgconfig(appstream): follow upstreams changes.
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Drop libgnome-desktop-3 dependency in favour of
    gsettings-desktop-schemas
  + Small updates to how app descriptions and addons are presented
    on the details page.
  + Fix handling of pending app installations when going online.
  + Better support for dark themes (particularly Adwaita-Dark).
  + Improvements to how app screenshots are loaded and presented.
  + Hide ‘Launch’ button if an application (for example, Wine)
    cannot be launched.
  + Make the UI clearer when loading information from flatpakref
    files.
  + Don’t update app metadata on start when download-updates is
    disabled.
  + Fix opening the updates list when clicking on an updates
    notification.
  + Fix state updates when installing flatpak apps or repos which
    are already installed.
  + Add Ctrl+Q as a keyboard shortcut for closing the window.
  + Rework timing and content of software update notifications.
  + Prevent uninstalled local apps from appearing in the installed
    apps list.
  + Support installation/uninstallation of addons for flatpak apps.
  + Improve presentation of age ratings for apps.
  + Fix a crash in the updates page.
  + Fix presentation of app permissions for fully sandboxed flatpak
    apps.
  + Fix deadlock on rpm-ostree systems.
  + Fix presentation of version number changes in right-to-left
    locales.
  + Error handling improvements for fwupd.
  + Performance improvements for ODRS on startup.
  + Improve presentation of firmware warning messages.
  + XML parsing performance improvements.
  + Automatically remove end-of-life flatpak runtimes.
  + Support updating flatpaks to their new name when they are
    renamed.
  + Update the GNOME Software icon.
  + Support more search results in the snap store.
  + Updated translations.
- Bump gs_plugin_api to 14, following upstream.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
- Replace pkgconfig(gnome-desktop-3) BuildRequires with
  pkgconfig(gsettings-desktop-schemas): follow upstream.
- Drop gnome-software-failed-offline-update-notification.patch:
  upstream code reworked.
* Tue Feb  9 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Fix package details not found for some packages.
  + Ignore harmless warnings when using unusual fwupd versions.
  + Updated translations.
* Tue Jan 19 2021 Stasiek Michalski <stasiek@michalski.cc>
- Remove hard dependency on zypp appdata plugin if other PackageKit backend is used
* Thu Nov 19 2020 Alynx Zhou <alynx.zhou@suse.com>
- Added gnome-packagekit as recommended dependency:
  gnome-software-launch-gpk-update-viewer-for-updates.patch needs
  gnome-packagekit to work (SLE only) (bsc#1178768).
* Tue Oct 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Enable parental control integration (deps are now packaged):
  + Add pkgconfig(malcontent-0) BuildRequires.
  + Replace -Dmalcontent=false meson parameter with
  - Dmalcontent=true.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
- Bump define _version to 3_38_0 (soversion) following upstream
  changes.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Add sysprof support for profiling jobs.
  + Add webflow and basic auth support to flatpak plugin.
  + Coalesce refresh operations where possible.
  + Correctly mark layered rpm-ostree local packages as removable.
  + Fix flatpak bundle installation.
  + Handle invalid snap auth data.
  + Improve flatpak progress reporting for transactions.
  + Improve the heuristic for detecting old-style AppStream
    override files.
  + Many performance improvements in many areas of the code.
  + Only delete the firmware archive if we downloaded it to the
    cache.
  + Show a pulsing progress bar if progress is unknown.
  + Support loading appstream files from custom install prefix.
  + Use the runtime fwupd version for the user agent.
  + Updated translations.
- Drop gnome-software-add-missing-headers.patch: fixed upstream.
- Add pkgconfig(sysprof-4) and pkgconfig(sysprof-capture-4)
  BuildRequires: new dependency.
- Add gnome-software-no-static-lib.patch: do not install a static
  library.
- Split out library package libgnomesoftware-3_37_92.
* Wed Aug  5 2020 Yifan Jiang <yfjiang@suse.com>
- Update gnome-software-add-missing-headers.patch: add more devel
  headers in lib/meson.build (glgo#GNOME/gnome-software!446).
* Thu Jul 30 2020 Erico Mendonca <erico.mendonca@suse.com>
- Add gnome-software-add-missing-headers.patch: add missing devel
  headers referenced by gnome-software.h (bsc#1174849).
* Mon Jun  8 2020 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-software-failed-offline-update-notification.patch:
  plugin-loader: handle offline update errors properly(bsc#1161095,
  glgo#GNOME/gnome-software!471).
* Fri May 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Add distro upgrade css for the HC theme.
  + Check if a stock icon actually exists in the theme.
  + Correctly mark layered local packages as removable.
  + Fine-tune F32 upgrade banner position and font.
  + Fix loading if applications directory does not exist.
  + Fix the progress info required for the loading page.
  + Handle invalid snap auth data.
  + Improve performance when showing lots of applications.
  + Only delete the installed firmware archive if we downloaded it.
  + Properly check if an flatpak application is a runtime.
  + Show the correct state for local packages without AppData.
  + Updated translations.
* Thu May 21 2020 Jonathan Kang <songchuan.kang@suse.com>
- Re-autostart GNOME Software and re-enable its search extension
  (bsc#1168861, bsc#1157928).
* Wed Mar 11 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + gs-app-row: Remove ‘show-folders’ functionality.
  + Updated translations.
* Wed Mar  4 2020 bjorn.lie@gmail.com
- Update to version 3.35.92:
  + Fix crash when viewing application details.
  + Fix “thrice daily” check running every 3 days.
  + Improve the appearance of the front page banners.
  + Show the correct upgrade banner contents when a reboot is
    required.
  + Updated translations.
* Thu Feb 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Add an info bar about automatic updates.
  + Avoid rpm-ostree downgrade error when doing distro upgrade.
  + Click on stars to open review dialog in the details view.
  + Fix loading of icons from AppStream YAML.
  + Fix weird font sizes in the batter.
  + Hide any in-app notifications when closing the main window.
  + Integrate better with snapd.
  + Only ignore flatpak estimated progress if >10%%.
  + Remove color stripes on categories in the Explore page.
  + Remove support for Shell extensions.
  + Remove webapp support.
  + Reset star rating when loading an unrated app.
  + Sort applications using locale based algorithms.
  + Stop snaps from being automatically updated.
  + Updated translations.
- Add pkgconfig(ostree-1) BuildRequires: new dependency.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.2:
  + Add missing OARS content rating descriptions.
  + Add new plugin for restricting access to apps.
  + Avoid a UI crash when switching modes.
  + Build libmalcontent dependency on Fedora CI.
  + Correctly distinguish empty content ratings from missing ones.
  + Correctly set the application state if autoupdate is in
    progress.
  + Do not show a crazy error when installing packages.
  + Do not show non-applications in the installed panel.
  + Download Flatpak updates in the correct installation.
  + Expose snap channels as app alternates.
  + Fix a crash on 32-bit systems.
  + Fix manual detach when updating removable device firmware.
  + Fix third party repo enabling not working.
  + Hide add/remove shortcut buttons for parentally filtered apps.
  + Improve some front page banners.
  + Invalidate caches when adding or removing remotes.
  + Make flatpak more thread-safe to fix some crashes.
  + Match the exact ID when refining a wildcard.
  + Only set the app row's buttons as destructive when they remove
    an app.
  + Rework age ratings handling to avoid hard-coded list.
  + Set the shell extension origin correctly in all cases.
  + Show the channel for snaps.
  + Speed up the flatpak plugin in some situations.
  + Use plugin API to launch apps from install notification.
- Pass -Dmalcontent=false to meson: Disable parental control
  integration for now, as we don't have malcontent packaged yet.
* Wed Jan 29 2020 Lubos Kocman <lubos.kocman@suse.com>
- Apply polkit workaround also for Leap 15.2
  bsc#1157928 poo#62762.
* Thu Nov 28 2019 Frederic Crozat <fcrozat@suse.com>
- Don't start gnome-software at startup and disable its search
  extension on SLE until bsc#1157928 is fixed properly.
* Wed Nov 27 2019 Yifan Jiang <yfjiang@suse.com>
- Rebase gnome-software-launch-gpk-update-viewer-for-updates.patch
* Mon Nov 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Do not show a crazy error when installing packages.
  + Do not show non-applications in the installed panel.
  + Download Flatpak updates in the correct installation.
  + Fix a potential threading crash when using flatpak.
  + Fix a small memory leaks.
  + Set the shell extension origin correctly in all cases.
  + Speed up flatpak loading in some situations.
  + Updated translations.
- Drop gnome-software-fwupd-dependency.patch: Fixed upstream.
* Tue Nov 19 2019 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-software-fwupd-dependency.patch: fwupd: Fix compile
  with old versions of fwupd (bsc#1156960,
  gh#hughsie/gnome-software!362).
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix firmware updates where the device needed a manual detach.
  + Fix installing webapps.
  + Fix signal blocking for search.
  + Fix third party repo enabling.
  + Hide the shortcut buttons for parentally filtered apps.
  + Make disabled flatpak remote enabling work.
  + Show snap channels as app alternates.
  + Show the correct application when clicking from the GNOME Shell
    menu.
  + Updated translations.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Add a link to the privacy policy in the review dialog.
  + Add and improve many overview banners.
  + Add support for download scheduling using Mogwai.
  + Allow installing locale data automatically.
  + Allow snaps to be shown by AppStream ID.
  + Don't apply drop shadow on stock symbolic icons.
  + Don't install queued apps when the network changes and is
    metered.
  + Fix the 'localised in my language' kudo.
  + Hide addons that are not available in repos.
  + Localize ESRB content rating strings.
  + Never show the installation progress bar going backwards.
  + Notify the user when an application can escape the sandbox.
  + Refactor screenshots and hide those unavailable when offline.
  + Select the rating systems selected based by territory.
  + Use smaller default size for main window when required.
  + Updated Translations.
* Thu Jul 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.4:
  + Fix an issue that led to some packages with multiple appdata
    files not correctly showing up on the updates page.
  + Fix various problems with flatpak branch handling that were
    causing issues with freedesktop.org runtime updates.
  + Fix flatpak update versions to correctly show up.
  + Various other minor bug fixes.
* Fri Jul  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(valgrind) BuildRequires, and pass valgrind=false
  to meson. Fixes build for arm, and we do not really need valgrind
  integration.
* Fri May 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.3:
  + Add missing XbSilo locking, hopefully fixing a large number of
    reported crashes.
  + Fix a regression that caused the fonts category to go missing.
  + Show a placeholder on the details page when we don't have the
    actual icon.
  + Plug a large memory leak.
  + Use nicer arrows for version numbers on the updates page.
  + Fix an issue that led to screenshots not being correctly scaled
    on hidpi.
  + flatpak:
  - Fix several double-uses of GErrors.
  - Handle failure of a libflatpak function updating permissions.
  + rpm-ostree: Implement what-provides decompose.
* Tue May  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Avoid showing a review more than once.
  + Correctly update progress bar when downloading packagekit
    distro upgrades.
  + Fix a crash when closing the updates dialog before the content
    has loaded.
  + Fix CTRL+F not working right in certains conditions.
  + Set 022 umask to make sure flatpak system helper process can
    read the files we've written.
  + rpm-ostree:
  - Implement getting the repo list, and enabling and disabling
    repos.
  - Implement provides search.
  - Make layered apps not discoverable in the UI.
  + Various other minor bug fixes.
  + Updated translations.
* Tue Apr 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Add drop shadows to app icons.
  + Various fixes to initial loading screen.
  + Show a generic icon instead of empty space if we failed to load
    the app icon.
  + Update featured banners for Maps and Blender.
  + Update featured app IDs.
  + Fix a crash due to missing locking.
  + Fix missing back button under certain conditions.
  + Fix loading AppSteam data from .yml.gz files.
  + Fix an issue that caused flatpak repo to not be correctly shown
    when it matched an existing packagekit repo name.
  + Hide the fwupd Vendor repo in the repos dialog.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + trivial: Don't crash when installing a web-app.
  + Remove reference to obsolete Ubuntu review plugin from README.
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Add two missing description strings for flatpak permissions.
  + Only show permissions for flatpak apps and not for e.g. fonts.
  + Fix flatpak permissions to correctly show up for available
    apps.
  + Hide various details page items that don't make sense when
    showing .flatpakrepo files.
  + Fix an issue that caused descriptions to sometimes not get
    correctly loaded.
  + Sort the items in the Source drop down.
  + Don't show error notifications for background download and
    refresh errors.
  + Fix an issue that could cause an explosion of "A restart is
    required" notifications.
  + Various flatpak plugin fixes to make it correctly match the
    data when multiple flatpak repos are available.
  + Fix the rpm-ostree plugin to correctly convert remote dbus
    errors.
  + Updated translations.
* Mon Feb 25 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix showing the installed check mark on tiles.
  + Fix crashes in the packagekit plugin due to missing locking.
  + Add back support for appstream data in
    /var/{cache,lib}/app-info directories that accidentally got
    left out with the libxmlb rewrite.
  + Update the featured banner for gnome-chess.
  + Fix the details page alignment when only one screenshot is
    shown.
  + Move the Update button to the right hand side on the details
    page.
  + Fix enabling repos when installing codecs through the extras
    page.
  + Remove the Sundry folder and sync the apps in the Utilities
    folder with gnome-menus 3.31.90.
  + Improve various content rating texts.
  + Drop workarounds for locales with codesets.
  + Use the currently selected icon theme for stock icons.
  + Don't hide compulsory apps in the category views.
  + Use the SPDX-License-Identifier in all source files.
  + Remove various useless error prefixes, making flatpak and
    packagekit error messages shorter and easier to read.
  + flatpak:
  - Show the installation type (user, system) in the Source
    dropdown.
  - Let apps control the name suffix/prefix they have and don't
    force (Nightly) suffix for everything on the master branch.
  - Various fixes for matching flatpaks to appstream entries.
  - Distinguish between the same app coming from multiple
    remotes.
  + rpm-ostree:
  - Correctly resolve installed appdata files to package names.
  - Hook up percentage progress for install and remove.
  - Implement layered package install.
  - Implement locally downloaded rpm install.
  - Show the source of the packages when installing layered
    packages.
  - Various fixes making things more robust.
  + snap: Use new media API.
  + Updated translations.
* Thu Jan 17 2019 bjorn.lie@gmail.com
- Udpate to version 3.31.2:
  + Show permissions for installed flatpaks, and new permissions
    for updates.
  + Use libxmlb to parse AppStream XML, making gnome-software start
    up faster and use less memory.
  + Update the app icon.
  + Update categories for ESRA rating system
  + Improve various error messages to have more details
  + Fix an issue that caused incorrect version numbers to be shown
    for installed flatpaks.
  + Fix various thread safety related crashes.
  + Fix row unrevealing to not leave behind 2 pixels on the updates
    page.
  + Make the refresh button to actually refresh packagekit cache.
  + Fix various issues that could lead to cache refresh getting
    stuck.
  + Show updates available notifications even when automatic
    updates are disabled.
  + Fix counting apps in the updates applied notification.
  + Improve packagekit update loading code, hopefully making it
    more robust.
  + Fix an issue that could lead to the packagekit plugin
    activating on rpm-ostree based systems
  + Switch flatpak updates to use a single transaction, which lets
    us share more code (and bugs) with the command line flatpak
    utility.
  + Fix various issues with transitioning from the "Download" state
    to "Restart & Update".
  + Don't error out from update downloads if the ODRS server is
    unavailable.
  + Fix old updates accumulating in the OS Updates item.
  + Various flatpakref installation fixes.
  + Fix opening the details page when clicking on "Show Details" in
    GNOME Shell.
  + Fix opening shell extensions details from GNOME Tweaks.
  + Various fixes for initial loading state.
  + Add a separate "Download" step for packagekit offline updates,
    so that "Restart & Update" is instant.
  + Fix a version comparison issue that led to package updates
    sometimes showing as downgrades in the OS Updates section (this
    needs latest appstream-glib).
  + Show the refresh button when the updates page is in the failed
    state.
  + Notify about offline updates only after they are fully
    downloaded.
  + Fix a memory corruption issue on 32-bit arches that made
    gnome-software very crashy.
  + Fix an issue with stuck back button on the details page after
    closing and reopening gnome-software.
  + Make distro upgrades to Fedora N+2 release show up correctly.
  + Various flatpak plugin fixes.
  + Allow opening CAB files that include more than one update.
  + Fix critical warnings when quickly switching between category
    pages.
  + Small memory leak fixes.
  + Updated translations.
- No longer pass -Dubuntu_reviews=false and -Dubuntuone=false to
  meson, no longer needed, dropped upstream.
- Drop gnome-software-fix-installing-flatpakref.patch: Fixed
  upstream.
- Add pkgconfig(goa-1.0) and pkgconfig(xmlb) BuildRequires: New
  dependencies.
- Bump gs_plugin_api to 13 following upstreams changes.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Icon redesign.
  + Switch to using window menus instead of app menu.
  + Add a source selection drop down to details pages.
  + Move the search button to the left side in the header bar.
  + Various other minor UI tweaks.
  + GtkBuilder UI file changes to pave the way for an eventual GTK4
    port (please file issues for any UI layout regressions if you
    notice any!).
  + Various internal plugin loader fixes and cleanups.
  + Remove the steam plugin.
  + Simplify the details page loading.
  + Fix an issue that caused icons to not get loaded for locally
    installed flatpaks.
  + Update Fedora distro upgrades text.
  + Avoid a critical warning in the fwupd plugin when the device
    vendor is not set.
  + Show verified developers for snaps.
  + Updated translations.
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Add flatpak Recommends: Users should not have to figure out that
  this package is needed for flatpaks to work out of the box
  (boo#1118040).
* Tue Dec 18 2018 bjorn.lie@gmail.com
- Update to version 3.30.6:
  + Fix various thread safety related crashes.
  + Fix row unrevealing to not leave behind 2 pixels on the
    updates page.
  + Make the refresh button to actually refresh packagekit cache.
  + Fix various issues that could lead to cache refresh getting
    stuck.
  + Show updates available notifications even when automatic
    updates are disabled.
  + Fix counting apps in the updates applied notification.
  + Improve packagekit update loading code, hopefully making it
    more robust.
  + Fix an issue that could lead to the packagekit plugin
    activating on rpm-ostree based systems.
  + Switch flatpak updates to use a single transaction, which lets
    us share more code (and bugs) with the command line flatpak
    utility.
  + Fix various issues with transitioning from the "Download" state
    to "Restart & Update".
  + Don't error out from update downloads if the ODRS server is
    unavailable.
  + Fix old updates accumulating in the OS Updates item.
  + Various flatpakref installation fixes.
  + Fix opening the details page when clicking on "Show Details" in
    GNOME Shell.
  + Fix opening shell extensions details from GNOME Tweaks.
  + Various fixes for initial loading state.
  + Updated transactions.
* Tue Nov 20 2018 sckang@suse.com
- Add gnome-software-fix-installing-flatpakref.patch: flatpak: Fix
  installing flatpakrefs if the remote is already configured
  (glgo#GNOME/gnome-software#517).
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.5:
  + Fix build with appstream-glib 0.7.14.
- Changes from version 3.30.4:
  + Add a separate "Download" step for packagekit offline updates,
    so that "Restart & Update" is instant.
  + Fix a version comparison issue that led to package updates
    sometimes showing as downgrades in the OS Updates section (this
    needs latest appstream-glib).
  + Show the refresh button when the updates page is in the failed
    state.
  + Notify about offline updates only after they are fully
    downloaded.
  + Updated translations.
* Thu Oct 18 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Fix a memory corruption issue on 32-bit arches that made
    gnome-software very crashy.
  + Fix an issue with stuck back button on the details page after
    closing and reopening gnome-software.
  + Make distro upgrades to Fedora N+2 release show up correctly.
  + Various flatpak plugin fixes.
  + Allow opening CAB files that include more than one update.
  + Fix critical warnings when quickly switching between category
    pages.
  + Small memory leak fixes.
  + Updated translations.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Localize the polkit policy file.
  + Display ongoing app-installation at top of the list.
  + Update apps in display order.
  + Fix autoupdates triggering in a feedback loop.
  + Tweak the prefs dialog layout.
  + Various fixes to the flatpak plugin, making its state keeping
    more robust.
  + Fix flatpak errors to show up instead of a generic "Aborted"
    error.
  + Avoid triggering reboots for online updatable apps (flatpak).
  + Make rpm-ostree updates work again.
  + Fix an issue that caused duplicate lines in 'OS Updates' on
    rpm-ostree based systems.
  + Compiler warning fixes.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix an issue that caused duplicate lines in 'OS Updates'.
  + Filter the application restart notification to actual desktop
    apps.
  + Fix an issue that caused automatic updates to fail during
    download phase.
  + Avoid showing duplicates in the featured apps when an app is
    available as both flatpak and a package.
  + Fix an issue that caused gnome-software to use 100%% of CPU when
    doing automatic updates.
  + Lower IO priority for gnome-software so that other apps stay
    responsive during flatpak installs.
  + Various fixes and wording changes to automatic updates
    notifications.
  + Only show "Examine Disk" button when baobab is available.
  + Leak and correctness fixes in the snap plugin.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + New stable release.
- Changes from version 3.39.2:
  + Do not go 'back' to a previous application details panel.
  + Don't crash if when getting the fwupd locked status.
  + Download updates automatically when required.
  + Fix dark theme support.
  + Hide screenshot and support widgets when no screenshots.
  + Ignore non-interactive generic errors.
  + Implement distro upgrade downloading when using rpm-ostree.
  + Only update the update check timestamp when it succeeds.
  + Open the WiFi panel when clicking the Network Settings button.
  + Rotate featured apps on the overview page.
  + Simplify the updates panel.
  + Use FlatpakTransaction to install, remove and update.
  + Use new display name for the Snap publisher.
  + Use the full name for the ESRB ratings descripion.
- Update spec file:
  + Use new option names in meson call.
  + Remove lang package from recommended packages as it already
    supplements main package (same effect, it's redundant).
* Thu May 10 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Show a better notification when a local file or URI is not
    supported.
  + snap: Use ODRS for reviews.
  + Updated translations.
* Wed May  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Add a warning when enabling the LVFS remote.
  + Show a notification when failing to open an url or a local
    file.
  + Fix multiple flatpak refreshes with new libflatpak.
  + Build fixes for FreeBSD.
  + Icon loading fixes for snap.
  + Updated translations.
* Fri Apr 20 2018 lnussel@suse.de
- require fwupd, gnome-software doesn't work without (boo#1090042)
* Thu Apr 19 2018 sckang@suse.com
- Mark gnome-software-launch-gpk-update-viewer-for-updates.patch
  as PATCH-FIX-OPENSUSE, as Leap 15 need it as well (boo#1090042).
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Fix a regression with opening results from gnome-shell search.
  + Show "Source: " tag in gnome-shell search when we have
    multiple matches.
  + Improve unknown license tag color scheme on details page.
  + Don't show installed icon on app tiles while still installing.
  + Fix empty items appearing under OS Updates.
  + Fix a regression that caused duplicate results in codec search.
  + Fix an issue with passing username/password to packagekit
    proxy.
  + Avoid crashing during first run with no network access.
  + A number of rpm-ostree fixes, making it possible to trigger
    offline updates.
  + Stop searching multiple times on search page.
  + Update Fedora third party repositories "Find out more..." link.
  + Fix an issue with in-app notifications failing with invalid
    markup errors.
  + Improve purchase failure handling for the snap store.
  + Fix a possible crash in snap plugin when adding screenshots.
  + Various other crash and correctness fixes.
  + Updated translations.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Fix the build on NixOS.
  + Fix purchasing not working after authentication.
  + Revert a commit that led to flatpak updates failing without any
    feedback.
  + Make front page featured tile corners round to match other
    tiles.
  + Fix in-app notification close button alignment.
  + Several fixes to make error notifications more useful.
  + snap: Fix invalid metadata after cancelled refine.
  + snap: Launch command line snaps with 'snap run'.
  + Updated translations.
* Tue Mar 13 2018 sckang@suse.com
- Add gnome-software-launch-gpk-update-viewer-for-updates.patch:
  Don't launch gnome-software when clicking the updates
  notification. Launch gpk-update-viewer instead (bsc#1077332).
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Removal of global plugin cache, simplifying gnome-software
    internals.
  + Software Repositories dialog got another batch of improvements
    and UI changes.
  + GNOME Shell Extensions repository and fwupd repositories are
    now shown in the Software Repositories dialog.
  + Shell extensions handling through PackageKit was improved,
    fixing a long standing bug where we were unable to remove shell
    extension packages.
  + Category page rewrite that landed earlier this cycle went
    through UI review and got a number of fixes.
  + Package version comparison in the updates dialog was fixed and
    should no longer incorrectly show updates as downgrades.
  + Distro upgrade notifications are now rate limited to once per
    week.
  + Install buttons in codec install view that got lost in the
    3.22 cycle are now back.
  + Various paper cuts with distro upgrades were fixed.
  + Various fixes to installing apps from yum repos that have
    enabled=0 enabled_metadata=1.
  + Various other correctness and warning fixes.
- Drop gnome-software-first-run-dialog.patch: fixed upstream.
* Tue Mar  6 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Mar  6 2018 dimstar@opensuse.org
- Add gnome-software-first-run-dialog.patch: Revert "Fix first run
  dialog racing with gnome-software shell startup". This caused the
  first run dialog to appear when gnome-software starts in the
  background with 'gnome-software --gapplication-service'.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + The Software Sources dialog was renamed to Software
    Repositories and rewritten.
  + Fedora Workstation third party repository handling was
    rewritten and should be more robust.
  + Improved handling of metered network connections, making sure
    we cancel any downloads when changing to a metered connection.
  + Limit the number of parallel operations depending on the
    installed CPU.
  + Improved handling of pending installs when there's no network
    connection.
  + Unused ostree and rpm plugins were dropped.
  + Switch from GtkSpell to gspell.
  + Improve alignment on the updates page.
  + Do not show missing screenshot error for fonts that have
    screenshots.
  + Fix various issues on Ubuntu when purchasing apps.
  + Fix an issue that led to duplicate categories appearing on the
    overview page.
  + Various memory leak and correctness fixes.
  + Updated translations.
- Replace pkgconfig(gtkspell-3-3.0) BuildRequires with
  pkgconfig(gspell-1), following upstreams changes.
- Drop pkconfig(rpm) BuildRequires: no longer needed.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Add gnome-software-local-file.desktop file for testing under
  GNOME:Next devel project.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Add missing locking to gs_plugin_cache_remove(), fixing a
    possible crash.
  + Fix various memory leaks spotted by valgrind.
  + Fix a possible crash triggered by the fwupd plugin.
  + Do not emit critical warnings when reviewing OS Updates.
  + fwupd: Use the custom user-agent when downloading firmware.
  + overview page: Fix a crash when we have no featured apps.
  + packagekit: Implement repository enabling.
  + Fix hover CSS for "unknown" and "nonfree" license buttons.
  + Updated translations.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Work around Firefox deleting rpm/deb files downloaded to /tmp
    when closing.
  + Log errors to console when starting from command line.
  + Improve SPDX ID parsing when working out if it is 'free'.
  + Fix:
  - Crashes in the repos plugin due to missing locking.
  - A critical when updating (flatpak) packages live.
  + Do not:
  - Enable distro-upgrades when updates are disabled.
  - Require the user to keep clicking 'More reviews' after each
    click.
  - Crash when closing the source dialog while it is loading.
  + Fwupd:
  - Do not crash when trying to list a locked device.
  - Prepend the vendor name to the device name if not included.
  + Packagekit:
  - Do not crash when getting an invalid ID from PackageKit.
  - Support apt:// URLs.
  + Various fixes to the snap plugin.
  + Updated translations.
- Drop gs-add-locking-to-the-repos-plugin.patch: fixed upstream.
- Update Url to https://wiki.gnome.org/Apps/Software: current
  Software's web page.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Redesigned category view.
  + Better notifications for completed distro upgrades.
  + Number of test suite fixes to pave way for continous
    integration tests.
  + Improved support for running on low res displays.
  + Various fixes to internal state handling.
  + Allow linking to specified proprietary licenses.
  + Don't use versioned subdirectories under
    ~/.cache/gnome-software.
  + Only show in-app notifications for interactive user actions.
  + Various fixes for flatpak, fwupd, and snap support.
  + Updated translations.
- Drop intltool BuildRequires: No longer needed since upstream
  switched to gettext.
* Fri Mar  2 2018 bjorn.lie@gmail.com
- Update to version 3.26.7:
  + Use less space on low resolution displays.
  + Hide invalid apps we don't know how to install.
  + Rate limit distro upgrade notifications once per week.
  + Make category name sorting case insensitive.
  + Add back install buttons to codec install view.
  + Update flatpak remote metadata when refreshing.
  + Remove fedora-tagger-usage plugin.
  + Various correctness and warning fixes.
  + Various fixes to the external appstream plugin.
  + Various fixes to the snap plugin.
  + Updated translations.
* Thu Feb  8 2018 bjorn.lie@gmail.com
- Update to version 3.26.6:
  + Improve alignment on the updates page.
  + Do not show missing screenshot error for fonts that have
    screenshots.
  + Fixes for third party repository handling in the sources
    dialog.
  + Fix various issues on Ubuntu when purchasing apps.
  + Fix building with gtkspell support.
  + Fix an issue that led to duplicate categories appearing on the
    overview page.
  + Various memory leak and correctness fixes.
  + Show package descriptions when installing packages through the
    dbus API.
  + Revert a commit that broke repo package install.
  + Updated translations.
- Pass enable-gtkspell=true to meson, ensure we build gtkspell
  support.
* Fri Jan 19 2018 bjorn.lie@gmail.com
- Update to version 3.26.5:
  + Add missing locking to gs_plugin_cache_remove(), fixing a
    possible crash.
  + Fix various memory leaks spotted by valgrind.
  + Fix a possible crash triggered by the fwupd plugin.
  + Do not emit critical warnings when reviewing OS Updates.
  + fwupd: Use the custom user-agent when downloading firmware.
  + overview page: Fix a crash when we have no featured apps.
  + packagekit: Implement repository enabling.
  + Fix hover CSS for "unknown" and "nonfree" license buttons.
  + Updated translations.
* Mon Jan  8 2018 zaitor@opensuse.org
- Update to version 3.26.4:
  + Fix crashes in the repos plugin due to missing locking.
  + Work around Firefox deleting rpm/deb files downloaded to /tmp
    when closing.
  + Do not require the user to keep clicking 'More reviews' after
    each click.
  + Fix a critical when updating (flatpak) packages live.
  + fwupd: Prepend the vendor name to the device name if not
    included.
  + Improve SPDX ID parsing when working out if it is 'free'.
  + packagekit: Do not crash when getting an invalid ID from
    PackageKit.
  + Do not crash when closing the source dialog while it is
    loading.
  + Updated translations.
- Drop gs-add-locking-to-the-repos-plugin.patch: Fixed upstream.
* Sun Nov 26 2017 zaitor@opensuse.org
- Add gs-add-locking-to-the-repos-plugin.patch: Add locking to the
  repos plugin so that we don't modify the priv->urls hash table
  concurrently from multiple threads (rh#1516536).
- Run spec-cleaner, modernize spec, use autosetup macro, no longer
  rm la files, not needed as we are using meson buildsystem.
- Drop update-desktop-files BuildRequires and no longer use
  suse_update_desktop_file macro, no longer needed.
- Explicitly pass enable-ubuntuone=false to meson.
* Wed Nov 22 2017 badshah400@gmail.com
- Update to version 3.26.3:
  + Fix a common crash in the fwupd plugin.
  + Make category translations on the details page show up.
  + Updated translations.
- Changes from version 3.26.2:
  + Various fixes to cancellable handling, making it more robust
    to cancel install/remove operations.
  + Fix a common crash in Fedora distro upgrades plugin.
  + Fix showing N+2 Fedora upgrades.
  + Fix flatpak updates inadvertently triggering a reboot.
  + Revert plugin GType registering changes that broke app
    "adopting".
  + Various flatpak plugin fixes.
  + Various snap plugin fixes.
  + Bump fwupd required dep to 0.9.7 and support building with new
    1.0.0 API.
  + Avoid erroring out for operations that return more than 500
    results (distro upgrades, getting gnome-shell extensions
    list).
  + Fix a few memory leaks.
  + Updated translations.
- Enable fwupd; introduces BuildRequires on pkgconfig(fwupd) >=
  0.9.7.
- Remove the enable-firmware switch from the meson build options;
  this option has been dropped by upstream.
* Fri Nov 10 2017 luc14n0@linuxmail.org
- Remove gnome-software-local-file.desktop from the package: It's
  not yet being shipped since it's still under tests (boo#941862).
- Drop %%icon_theme_cache_* and %%desktop_database_* post/postun
  scriptlets and %%glib2_gsettings_schema_requires macro: the
  functionality is covered by file triggers now.
* Tue Oct  3 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + external-appstream: Fix leak when getting a temp file name.
  + fwupd: Fix critical warning if the update URI isn't set.
  + packagekit: Fix crash if reporting progress with no current
    application.
  + gs-desktop-common: Fix "Addons" back to "Addon" in category
    IDs.
  + snap: Don't use a common SnapdClient.
  + Updated translations.
* Mon Sep 11 2017 jengelh@inai.de
- Update package summaries.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Use the new fwupd API in 0.9.7 to avoid when a reboot is
    required.
  + Pass the complete proxy settings to PackageKit.
  + Bugs fixed:
  - Do not crash when emitting an uncommon error message.
  - Do not show a critical warning with new versions of fwupd.
  - Do not show an error for a remote-less flatpakref
    application.
  - Don't refine PackageKit packages after we've been cancelled.
  - Fix a possible crash on 32 bit systems.
  - Fix GNOME Shell search results for snap applications.
  - Properly disable shell-extensions when not running GNOME
    Shell.
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Add a simple donation button on the details page.
  + The following bugs are also fixed:
  - Allow plugins to say that installation cannot be cancelled.
  - Fix displaying the info bar for the Shell Extensions
    category.
  - Use first featured snap as the featured app.
  + Updated translations.
* Wed Aug 16 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Add a simple donation button on the details page.
  + Do not crash if the child schema is invalid.
  + Don't log a warning when clicking the the 'more results' search
    entry.
  + Fixed subcategory names localization.
  + Ensure flatpak remote names are valid.
  + Fix critical warning with new versions of the fwupd daemon.
  + Updated translations.
* Sat Jul 22 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Add new rpm-ostree integration for Fedora Atomic Workstation.
  + Install the Flatpak runtime as part of the application install
    phase.
  + Split OS updates up into multiple sections and show the target
    version.
  + Support compatibility IDs when getting reviews from the ODRS.
  + Cancel plugin jobs if they take too much time.
  + Correctly find already installed flatpak runtimes.
  + Do not show an error for a flatpakref when broken remotes
    exist.
  + Don't show the screenshot section for runtimes.
  + Fix authentication prompt not showing when using snapd.
  + Make license buttons buttons actually look clickable.
  + Make the review moderator panel easier to use.
  + Only show snaps as sandboxed if snapd supports confinement.
  + Respect the per-user or per-system install preferences.
  + Return the correct installed state for user/system flatpak
    remotes.
  + Updated translations.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Add a banner designer utility.
  + Add the initial support to support purchasable apps.
  + Automatically install flatpak icon themes and GTK themes.
  + Restyle the updates panel to have a separate sections.
  + Show a notification in the updates page when the OS is end of
    life.
  + Show recently updated applications on the overview page.
  + Add snap self tests and provide more data to the details panel.
  + Allow compiling with newer versions of meson.
  + Do not crash when sending progress reports while refreshing.
  + Don't trigger systemd for every single offline update.
  + Ensure all related flatpak applications get installed.
  + Ensure we use the gnome-desktop support if enabled.
  + Fix searching for codecs on Ubuntu.
  + Show a better status messages when downloading metadata.
  + Show a pulsing progressbar if plugins do not report progress.
  + Show the PackageKit interactive dialog when required.
  + Support updating metadata from multiple fwupd remotes.
  + Updated translations.
- Pass -Denable-fwupd=false to meson, we do not have the needed
  fwupd in openSUSE.
- Test shipping gnome-software-local-file in GN again.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Switch to meson buildsystem.
  + Allow AppStream to be downloaded out-of-band per-user.
  + Bugs fixed:
  - Do not initialize plugins in every instance.
  - Fix the 'Show Details' context menu item in GNOME Shell.
  - Use headerbar in toolbar-mode in Unity.
  - Do not allow plugins to set the origin title in the UI.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Following the above: No longer pass disable-static,
  disable-firmware, enable-flatpak, enable-ostree, enable-rpm,
  enable-steam, enable-shell-extensions,
  disable-external-appstream, disable-tests to no longer existing
  configure, instead pass: enable-firmware=false,
  enable-ubuntu-reviews=false and enable-tests=false to meson
  macro. The "missing ones" are default on when building with
  meson.
- Add gtk-doc BuildRequires, needed now that we are using meson.
- No longer handle glib2_gsettings_schema_post(un) in post(un), no
  longer needed as filetriggers takes care of it.
* Mon May 15 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Fix a common crash when installing flatpakrepo files.
  + Show the headerbar in toolbar-mode when running in Unity.
  + Updated translations.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Use the unique id of an AsApp when creating a GsApp in
    gs-appstream.
  + Prevent potential abuse of an app list in the plugin-loader.
  + trivial: Add one more dep to the example spec file.
  + Fix popular-overrides.
  + Add the complete flatpak source as a keyword.
  + Load the application keywords after the origin keywords have
    been added.
  + trivial:
  - Use the correct type when removing applications.
  - Correctly clear custom widget CSS if the metadata key is
    cleared.
  - Update the feature tile widget if the app name or summary
    changes.
  - Prevent critical warning when trying to parse an invalid
    URI.
  - Update more tile widgets if the app name or summary change.
  + Fix destdir!=srcdir when running the flatpak tests.
  + Fix callback for gs_plugin_loader_url_to_app_async, fixing
    small memory leak.
  + shell-extensions: Use static URI to fetch extensions data.
  + Fix building the external-appstream plugin.
  + Do not show the origin comment in the details page.
  + Do not abort if a page does not handle the reload vfunc.
  + Updated translations.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Fall back to a stock icon for hardware drivers.
  + Fix a crash when removing an addon.
  + Respect the user/system preference when installing flatpakref
    files.
  + Make offline update triggering work when online updates are
    available.
  + Never include the size of the runtime in the installed size.
  + Use the developer name if set in preference to the project
    group.
  + Never show a remote snapd error in the authentication dialog.
  + Only auto-add snap provenance when running on Ubuntu.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Do not assume 'in AppStream' means 'is available'.
  + Updated translations.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Allow installing broken flatpakref files.
  + Do not reload the updates list when updates are in progress.
  + Reset the headerbar title when switching to the details page.
  + Unconditionally show things that are in progress in the
    Installed page.
  + Updated translations.
- Pass --disable-tests to configure: enabling the tests would
  require flatpak 0.9.1, which is not yet ready.
* Mon Feb 27 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Add support for RuntimeRepo in flatpakref files.
  + Allow the user to restart the currently running gnome-software
    instance.
  + Never show components without AppData files.
  + Initialize progress to zero right before and after processing
    an action.
  + Animate the removal of live updates.
  + Add YaST as a default folder in gnome-shell overview.
- Drop gnome-software-add-default-yast-appfolder.patch: merged
  upstream.
- Add pkgconfig(valgrind) BuildRequires: new depdenency.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Handle apt and snap URLs.
  + Show the updates panel with sections.
  + Sort the apps in the installed panel by kind.
  + Add a more detailed error message when AC power is required.
  + Do not hardcode the gnome-software application name.
  + Ensure firmware is downloaded when not cached.
  + Fix a rather large memory leak when loading Steam data.
  + Fix launching Flatpak apps after updating.
  + Install needed Flatpak runtimes when updating an app.
  + Only show the scary firmware warning for removable devices.
* Tue Jan 17 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Add an --install and --interaction CLI options.
  + Add the installed size of the apps in the installed view.
  + Always set a description for each notification.
  + Show an in-app notification when installed plugins are changed.
  + Use a set of stars to show the different star ratings.
  + The following bugs are also fixed:
  - Add a missing error check to fix a common crash on LiveDVD
    media.
  - Add thread locking in GsApp to fix some common crashes.
  - Allow upgrading to Fedora EOL releases.
  - Don't allow review actions when offline.
  - Ensure we actually schedule firmware updates for download.
  - Fix the getting of PackageKit and flatpak update details.
  - Hide some notifications when the new app is launched or the
    window is closed.
  - Hide the screenshot placeholder for input methods and
    langpacks.
* Tue Jan 17 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Add a setting for downloading updates on metered connections.
  + Add content rating interface for games.
  + Add support for pending updates that are applied on demand.
  + Add support for the flatpak DefaultBranch feature.
  + Allow showing an application review without a display name.
  + Convert the modal failure dialogs to in-app notifications.
  + Switch to using the ODRS server hosted by GNOME.
  + Bugs fixed:
  - Always get the newest screenshot for GNOME Shell extensions.
  - Avoid redownloading the same screenshots for different
    images.
  - Don't download updates when low on power.
  - Fix the growth in memory usage for every search request.
  - Never show a 'back' button when showing search results.
  - Show the search bar when the user does ctrl+f.
  + Updated translations.
- Pass --disable-external-appstream to configure: this is broken
  by design.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 3.22.5:
  + Fix local package installation.
  + Fix codec and printer driver installation for packages without
    appdata.
  + Fix update notes to show up on the Updates page.
  + Add support for "+" operator at the end of SPDX license
    identifiers.
  + Only show the scary firmware warning for removable devices.
  + Various fixes for flatpak support.
  + Fix several potential crashers.
  + Updated translations.
* Thu Dec  8 2016 zaitor@opensuse.org
- Update to version 3.22.4:
  + Add locking to GsApp to fix hard-to-debug thread related
    crashes.
  + Fix various top crashers listed on Fedora's retrace server.
  + Fix an issue that caused app addon install/removal to get
    triggered without user interaction.
  + Make flatpakref installation work.
  + Hide review buttons when there's no internet connection.
  + Updated translations.
* Thu Dec  1 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + Misc. fixes to the search results page.
  + Misc. flatpak bug and crasher fixes.
  + Correctly raise the codec search window under the Wayland
    session.
  + Improve spinner state handling on the updates page.
  + Make it possible to upgrade two Fedora versions at a time.
  + Fix a memory leak with every search request.
  + Don't show screenshot placeholder for add-ons that can't have
    screenshots.
  + Show an error if the screenshot download fails.
  + Get the screenshot metadata from the GNOME Shell Extension JSON
    data.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Large number of fixes and improvements for flatpak support.
  + Improved handling for flatpak repos with multiple branches.
  + Initial support for installing flatpakrepo files.
  + Fix a crash when searching for codecs.
  + Fix a crash when de-duplicating applications.
  + Speed improvements for loading appstream data.
  + Refactor snapd handling code using snapd-glib.
  + Show the search bar when the user does Ctrl+f.
  + Updated translations.
* Wed Oct 12 2016 zaitor@opensuse.org
- Add pkgconfig(flatpak) BuildRequires and pass --enable-flatpak to
  configure now that we have flatpak in openSUSE.
- Drop pkgconfig(xdg-app) BuildRequires: No longer needed as
  flatpak is now in place.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix several issues with flatpak bundles.
  + Fix installing local packages.
  + Fix a crash when failing to get an installed flatpak ref.
  + Speed up loading the details and overview pages.
  + Switch to using the ODRS server hosted by GNOME.
  + Updated translations.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Add a new section name in the Addons category for drivers.
  + Add a plugin to match a hardware modalias.
  + Do not hide the origin when installing or removing an app.
  + Do not show the screenshot fallback image for firmware or
    drivers.
  + Fix launching app's details from the installed notification.
  + Fix showing the source line in the installed panel.
  + Unbreak the GNOME Shell search provider.
  + Use the same padding as a GtkStackSwitcher.
  + Updated translations.
- Add pkgconfig(gudev-1.0) BuildRequires: Build GUDev support.
* Wed Aug 31 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + Add functionality to enable non-free sources
  + Show the device bootloader screenshot when required
  + The following bugs are also fixed:
  - Always return consistent results by allowing plugins to share
    a cache.
  - Ensure the search text is showing when going back to search
    results.
  - Only enable the firmware 'Install' button when the device is
    in the right mode.
  - Remove an app from the installed view when it's uninstalled.
  - Show percentage progress when installing firmware.
  + Updated translations.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Trivial bugfixes.
  + Updated translations.
* Mon Aug 15 2016 dimstar@opensuse.org
- Update to version 3.21.4:
  + Add a cancel button and progress information to the details
    page.
  + Add a dialog to confirm upgrade removals.
  + Add support for authenticating in plugins.
  + Add support for snaps.
  + Enable gtk-doc generation for documentation.
  + Show a new-style category list on the overview page.
  + Show origin information when applications are available from
    multiple sources.
  + Show sandboxing information for selected applications.
  + Show the star ratings in more places.
  + Support installing .flatpakrepo files.
  + Support launching applicatins using a appstream:// URL.
  + Bugs fixed:
  - Allow plugins to be enabled and disabled at runtime.
  - Always show the 'MyLanguage' kudo when in en_US locale.
  - Correctly trigger systemd offline updates when only
    processing OS updates.
  - Disable app folders feature when run outside GNOME.
  - Do not show buttons on the search results.
  - Do not use deprecated CSS properties.
  - Do not use deprecated fwupd API.
  - Ensure reviews are shown in the correct order.
  - Fix a crash when double clicking files.
  - Fix several UX issues when upgrading.
  - Show the 'More Reviews' button in the details panel.
  - Try really hard to have two rows of important categories.
  + Updated translations.
- Add pkgconfig(libsecret-1) BuildRequires: new dependency.
- Bump gs_plugin_api to 11, following upstream.
- Drop pkgconfig(xdg-app) BuildRequires: xdg-app is no longer
  supported, this is now formally called flatpak.
- Drop gs-Fix-underlinking.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to autoreconf as there
  is no patch left touching the build system.
* Thu Jul 14 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Add a --details-pkg option to the gnome-software binary.
  + Add support for flatpak packages.
  + Add a plugin to auto-add some license information.
  + Add depends, requires and conflicts at initialize time.
  + Add support for application key colors.
  + Export a set of headers to allow external plugins to be built.
  + Bugs fixed:
  - Do not crash if plugins are badly behaved.
  - Do not directly load pixbufs in the AppStream plugin.
  - Do not unconditionally invalidate the updates list on
    hardware hotplug.
  - Find the best AppSteam component when matching any prefixes.
  - Fix crash due to network change before app activation.
  - Fix launching various KDE4 applications.
  - Support getting cached content from /var/cache and
    /usr/share.
  + Updated translations.
- Rebase gs-Fix-underlinking.patch.
- Drop gnome-software-icon-crash.patch: Fixed upstream.
- Split out new devel sub-package, gnome-software now have header
  files and pkgconfig file.
* Thu Jul 14 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Add an initial loading panel when there is no metadata
  + Add an outline ostree plugin that just adds remotes as sources.
  + Add an unreviewable application quirk.
  + Add initial Steam support.
  + Add support for app shortcut addition/removal.
  + Add support for GNOME Shell extensions.
  + Allow free-but-unspecified SPDX tokens.
  + Allow widgets to use custom CSS in a generic way.
  + Do the PackageKit refresh as a background transaction.
  + Hide "Software Sources" menu when its action is disabled.
  + Make the distro upgrades dialog match the new mockup.
  + Split the 'size' property into size-installed and
    size-download.
  + Use a link instead of a button for history.
  + Use AppStream files for the popular, featured and extra
    category data.
  + Use dpkg-deb info to create a GsApp when double clicking on a
    .deb file.
  + Use FwupdClient from fwupd 0.7.0.
  + Use GdkPixbuf to parse icns files.
  + Use gsettings to enable/disable the 'sources' action.
  + Use the Fedora themed image for the upgrade banner.
  + When there are no trusted sources mark everything as
    non-3rd-party.
  + Bugs fixed:
  - Actually show the error dialog for an invalid file.
  - Allow all functions called by g_module_symbol() to fail.
  - Allow popular and featured apps to match any prefix.
  - Do not maintain a cache of applications in the plugin loader.
  - Do not re-request the distro-upgrade when switching pages.
  - Do not show ratings and reviews for some component kinds.
  - Do not show the distro-upgrade notification if the window is
    open.
  - Do not use the header bar on Unity.
  - Fix a crash when double clicking package files.
  - Fix live installing firmware.
  - Get the correct icon size when installing xdg-app bundles on
    HiDPI.
  - Hide the kudo details panel for non desktop components.
  - Load screenshots directly if their URLs point to local files.
  - Lower the limits for review text.
  - Make the provenance plugin non-specific to Fedora.
  - Move header bar button creation into individual pages.
  - Move the Install & Restart button below the upgrade banner.
  - Only show the session manager restart if there were any
    non-live updates.
  - Properly support multi-line .deb descriptions.
  - Show a 'Install All' button when all the updates can be
    installed live.
  - Show a modal dialog when downloading the distro-upgrade
    failed.
  - Show the upgrades banner even if there are no updates to
    show.
  - Use a cache file to respect the fedora-distro-upgrades
    cache-age.
  - Use GFile instead of a filename when converting apps.
- Pass --enable-ostree, --enable-rpm, --enable-steam and
  - -enable-shell-extensions to configure to ensure we build support
  for these.
- Drop gs-compile-against-old-appstream-glib.patch,
  gs-Fix-xdg-app-build.patch and gs-Fix-a-possible-crasher.patch:
  Fixed upstream.
- Add pkgconfig(rpm) BuildRequires: New dependency.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Always show the 'MyLanguage' kudo when in en_US locale.
  + Disable app folders feature when run outside GNOME.
  + Fix an issue with launching Epiphany web-apps.
  + Fix a number of issues with Fedora system upgrades.
  + Fix a possible crash when download-updates setting is changed.
  + Improve styling of software reviews and kudos.
  + Make the app folder dialog work again.
  + Support launching appstream://id.
  + Updated translations.
- Drop gnome-software-fix-app-folders.patch: Fixed upstream.
* Wed Jun 15 2016 zaitor@opensuse.org
- Add gnome-software-fix-app-folders.patch: Fix regression in
  app-folders. Patch from upstream stable branch (boo#979570).
* Sat May 28 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Fix several issues with system upgrades.
  + Fix several issues with the Ubuntu reviews dialog.
  + Fix an issue that caused incorrect package versions to be shown
    in the update panel.
  + Fix an issue that caused offline updates to not start under
    certain conditions.
  + Updated translations.
- Drop gs-compile-against-old-appstream-glib.patch,
  gs-Fix-underlinking.patch, gs-Fix-xdg-app-build.patch and
  gs-Fix-a-possible-crasher.patch: Fixed upstream.
- Following the above drop gnome-common BuildRequires and
  autoreconf call, we no longer have patches touching the
  buildsystem.
* Wed May 18 2016 zaitor@opensuse.org
- Add commits from upstream fixing various issues:
  + gs-Fix-underlinking.patch: Fix underlinking in the
    packagekit-origin plugin.
  + gs-Fix-xdg-app-build.patch: Fix the xdg-app build.
  + gs-Fix-a-possible-crasher.patch: Fix a possible crash in review
    ratings.
- Add gnome-common BuildRequires, and pass autoreconf since two of
  the above patches touch the buildsystem.
* Mon Apr 25 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Allow popular and featured apps to match any plugin.
  + Do not make the ODRS plugin depend on xdg-app.
  + Fix many of the os-upgrade issues and implement the latest
    mockups.
  + Fix several issues when running on Unity.
  + Make all the plugins more threadsafe.
  + Return all update descriptions newer than the installed
    version.
  + Show some non-fatal error messages if installing fails.
  + Use a background PackageKit transaction when downloading
    upgrades.
  + Updated translations.
- Add gs-compile-against-old-appstream-glib.patch: Fix build
  against the appstream-glib we currently have, patch from
  upstream git.
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 3.20.1:
  + Do not make the ODRS functionality depend on xdg-app.
  + Fix live installing firmware.
  + Support unlocking fwupd devices.
  + Updated translations.
- Drop gnome-software-PK-updates.patch: it has been disabled for
  two years.
* Mon Apr 11 2016 mgorse@suse.com
- Add gnome-software-icon-crash.patch: fix crash when unable to
  find icon (boo#974806 bgo#764921).
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Actually show the error dialog for an invalid file.
  + Fix a crash when double clicking package files.
  + Remove placeholder text from application details label.
* Mon Mar 14 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Allow all plugin functions to fail gracefully.
  + Hide the kudo details panel for non-desktop components.
  + Lower the limits for review text.
  + Do not show ratings and reviews for some component kinds.
  + Fix showing Ubuntu-specific reviews.
  + Get the correct icon size when installing bundles on HiDPI.
  + Never show star ratings on the category app tiles.
  + Only show one modal dialog at a time.
  + Updated translations.
- Bump gs_plugin_api to 9, following upstream.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Add an 'All' subcategory in the category shell.
  + Add ratings and review functionality for Ubuntu.
  + Install the xdg-app runtime as required automatically.
  + Show a confirmation dialog before reporting a review.
  + Show a guide label for the different star values.
  + Support installing local xdg-app bundles.
  + Correctly identify local packages with sources.
  + Do not add multiple search results for the same app.
  + Do not show xdg-app runtimes in the installed panel.
  + Escape markup before showing modal dialogs.
  + Updated translations.
- Add pkgconfig(gdk-pixbuf-2.0) BuildRequires: New dependency.
- "Reactivate" suse_update_desktop_file that got disabled by a
  mistake.
- Drop gnome-software-nouser-proxy.patch: Upstream only passes
  proxy settings on if polkit is preconfigured to authorize it.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Add end-user application review functionality.
  + Add support for upgrading the OS from one release to another.
  + Add support for xdg-app and Limba bundles.
  + Add tags to applications, and explain them in the details page.
  + Update the list of featured applications on the front page.
  + The following bugs are also fixed:
  - Add a missing tag to the software center metadata file.
  - PackageKit support is now optional.
  - Temporarily remove the remove button in the sources dialog.
  - Use versioned user cache directories to pick up new
    screenshots.
  + Updated translations.
- Add pkgconfig(gtkspell3-3.0) BuildRequires: new dependency.
- Add pkgconfig(xdg-app) BuildRequires: new optional dependency.
- Drop gnome-software-fix-screenshots.patch: fixed upstream.
- Rebase gnome-software-nouser-proxy.patch.
* Tue Feb  2 2016 zaitor@opensuse.org
- Add gnome-software-fix-screenshots.patch: Fix clashing screenshot
  names (bgo#761434).
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Use PackageKits distro-upgrade feature.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
* Thu Nov  5 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + Use the correct user agent string when downloading firmware.
  + Fix a crash in the limba plugin.
  + Fix installing web applications.
  + Updated translations.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix a regression in 3.18.1 that could lead to the background
    update monitor never finding any updates.
  + Fix an issue with getting package details for apps without
    AppData.
  + Updated translations.
* Tue Oct 13 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Do not force the cache refresh and delete otherwise valid
    packages.
  + Fix several potential crashes when navigating and when
    installing.
  + Get the new application icon for local packages after
    installation.
  + Improve cold start time by only parsing AppStream data once.
  + Make sure Characters and Disks show up in Utilities.
  + Only download the fwupd metadata signature once per day.
  + Show an empty space for no category results.
  + Show applications without AppData in the installed panel.
  + Updated translations.
* Fri Oct  9 2015 zaitor@opensuse.org
- Add missing %%{name}-lang Recommends: We want translations!
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix getting firmware updates by parsing the metadata correctly.
  + Make the application menu path correct in RTL locales.
  + Don't keep the application running forever when run as a search
    provider.
- Rebase gnome-software-nouser-proxy.patch.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Better theming for the category sidebar.
  + Use standard size icon in the about dialog.
  + Support mouse back button for going back in dialogs.
  + Fix incorrect alignment on the front page in RTL languages.
  + Misc other minor bugs fixed.
  + Updated translations.
* Wed Sep  2 2015 dimstar@opensuse.org
- Do not ship gnome-software-local-file.desktop: gnome-software is
  not yet able to handle local RPM files on openSUSE (boo#941862).
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + extras: Correct the plural version of a translatable string.
  + trivial: Update a translator comment.
  + Remove margins in the Add to Folder and Updates dialogs.
  + Correctly align labels and checkmarks in the Add to Folder
    dialog.
  + offline updates: Use CSS to style the error message details.
  + menu spec plugin: Use context to translate subcategory titles.
  + Updated translations.
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Improvements:
  - Add basic support for Limba bundles.
  - Automatically download new firmware metadata from LVFS.
  - Hide updates UI on managed systems.
  - Show a new notification when security updates remain
    unapplied.
  - Show installation progress when installing applications.
  - Use some new applications to the picked category.
  + Bugs fixed:
  - Do not show applications that are not available when
    searching by category.
  - Don't crash when launching an app that has no desktop ID.
  - Don't show applications without AppData in the category view.
  - Fix a possible race and crash when loading icons.
  - Fix locking in the AppStream code to fix several crashes.
  - Use better error messages on offline update failure.
  - Withdraw the notification when prepared update gets
    invalidated.
  + Updated translations.
* Mon Aug  3 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Improvements:
  - Port to SoupSession.
  - Make fwupd dependency automagic.
  + Bugs fixed:
  - Fix a regression from the previous unstable release that made
    it impossible to install updates.
  - Fix a crash in the screenshot loader.
  - Fix a crash in the sources dialog.
  - Fix a crash when installing rpms that lack description.
  - Wrap long descriptions in the update dialog.
  + Updated translations.
* Mon Aug  3 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Support getting firmware updates through the fwupd daemon.
  + Use a smaller number of tiles on the front page on small
    monitors.
  + Rework internal modulesets, making it easier to edit the list
    of featured apps.
  + Revert back to using a hand-picked list of featured apps.
  + Several improvements to the sources dialog.
  + Show better human readable names when searching for font
    scripts.
  + Show a spinner while loading the data for the update history
    dialog.
  + Updated translations.
- Bump gs_plugin_api to 8, following upstream.
- Add iso-codes requires: new runtime dependency.
- Pass --disable-firmware to configure for now: we do not yet have
  the dependencies available.
* Mon Aug  3 2015 zaitor@opensuse.org
- Update to version 3.16.5:
  + Show installation progress when installing apps.
  + Several improvements to featured app banners.
  + Fix a possible crash when launching an installed app.
  + Update the styling of the history dialog to make sure
    unclickable rows don't appear clickable.
  + Make sure apps that aren't installable are properly hidden in
    the category view.
  + Fix an issue that caused "Source: Unknown" to be shown in the
    app details view.
* Sun Jun 14 2015 zaitor@opensuse.org
- Update to version 3.16.4:
  + Fix a frequent crash in appstream plugin.
  + Fix a critical warning when opening the app folder dialog.
  + Fix a possible crash when changing the download-updates option
    in gsettings.
  + Hide updates UI on managed systems.
  + Improve the error dialog for failed offline updates.
  + Workaround text coming up as selected in the updates dialog.
- Add pkgconfig(polkit-gobject-1) BuildRequires: New dependency.
* Fri Jun  5 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix a crash in the screenshot loader.
  + Fix a crash when installing rpms that lack description.
  + Fix a crash under Wayland when installing codecs.
  + Avoid scaled up fonts on non-hidpi displays.
  + Wrap long descriptions in the update dialog.
  + Reduce network timeouts to one minute.
  + Several improvements to the sources dialog.
  + Show better human readable names when searching for font
    scripts.
  + Updated translations.
- Add iso-codes Requires: New runtime dependency.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Remove redundant OK button from the updates installed
    notification.
  + Display a better human readable title for printer drivers.
  + Show a better UI for offline update failure dialog.
  + Set default actions for the update done notifications.
  + Allow searching for packages via the API without appdata.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Correctly save HiDPI images to HiDPI directories.
  + Scroll the contents of the error message dialog.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + This unstable release adds the following features:
  - React to theme changes.
  - Rebase the HighContrast theme.
  + This release fixes the following bug:
  - Fix HiDPI scale factor calculation.
  - Align section headings in all views.
  - Fix 'installed' overlays when using the HighContrast theme.
  - Fall back to showing the top level category when no sub
    category exists.
  - Fix a crash when using the pending applications feature.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Enable kinetic scrolling in updates dialog.
  + This release fixes the following bug:
  - Always ensure that the back entry focus widget is valid.
  - Don't show small screenshots on HiDPI hardware.
  - Fix a crash when starting GNOME Software for the first time.
  - Only show compatible projects when getting the featured
    list.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Add a new panel for displaying session service results.
  + Add a new version of the Modify interface.
  + Require AppData for all available packages.
  + Use the new mockups for the 3rd party source install dialogs.
* Fri Feb 27 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Add support for unavailable packages.
  + Use new API from libappstream-glib for tokenizing the search
    string.
  + Bugfixes:
  - Add some more prefer-GTK rules for applications that ship
    both.
  - Delay the updates-changed notification for a few seconds.
  - Do case-insensitive searching of suitable keywords.
  - Fix color of add button on add to app folder dialog.
  - Fix searching for keyworks with special chars.
  - Update Inkscape featured splash.
  - Use an AsIcon internally to simplify a lot of complex code.
  + Updated translations.
- Rebase gnome-software-add-default-yast-appfolder.patch and
  gnome-software-nouser-proxy.patch.
* Fri Feb 27 2015 zaitor@opensuse.org
- Update to version 3.15.2:
  + Updated translations.
* Fri Feb 27 2015 zaitor@opensuse.org
- Update to version 3.14.3 (boo#916784):
  + Bugfix:
  - Fix several possible crashes when clicking the back button.
  - Fix a crash in the screenshot loader.
  - Show an error message when we fail to load details about a
    local file.
  - Make sure back button always leads back to overview.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + New Features:
  - Add the origin as a keyword if it's not the majority source.
  - Support the LOCAL AppStream icon type.
  + Bugfix:
  - Do not fail to get popular apps if the AppStream data is
    invalid.
  - Do not show a random white line above the star rating widget.
  - Do not show empty app boxes if no popular results are
    available.
  - Do not try to download local web-app icons.
  - Fix screenshot loading with --details.
  - Use blue stars for the user-ratings rather than yellow/gold.
* Thu Oct 30 2014 dimstar@opensuse.org
- Split libzypp-plugin-appdata out of gnome-software to be able to
  easier maintain updates.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + New Features:
  - Load 128x128 icons if they are installed on HiDPI hardware.
  - Try to load HiDPI screenshots on HiDPI hardware.
  + Bugfix:
  - Always load the fallback icon at 64x64 size.
  - Avoid flickering the spinner during find-as-you-type.
  - Avoid restarting spinner animation when repeatedly calling
    start.
  - Clear all existing applications if the store was invalidated.
  - Destroy the sources dialog when it's closed.
  - Disable text shadow for the updates counter label.
  - Don't allow cancelling appstream plugin plugin startup.
  - Don't crash when the moduleset data is not yet installed.
  - Don't ignore duplicate searches.
  - Don't show addons that are in unavailable state.
  - Don't warn for cancelled operations.
  - First run dialog nonresizable and corrected margins.
  - Fix a race with displaying results from shell search
    provider.
  - Make --details work again.
  - Make search cancelling quicker.
  - Plug a leak when adding apps to the list of updates.
  - Plug a memory leak when refining addons.
  - Reload the all the shells when the AppStream metadata
    changes.
  + Updated translations.
- Bump gs_plugin_api to 7, following upstream.
* Tue Oct  7 2014 dimstar@opensuse.org
- Add gnome-software-nouser-proxy.patch: Do not pass proxy settings
  between user session and packagekitd. openSUSE does not grant the
  required polkit privileges, as user settings should not have an
  impact on the package manager in our view. The proxy settings for
  packagekitd are handled by libzypp/libproxy and are loaded from
  yast proxy settings.
* Mon Oct  6 2014 dimstar@opensuse.org
- Make libzypp-plugin-appdata a noarch package (It's a shell script
  only).
- Enhance InstallAppdata.sh to correct permissions in
  /usr/share/app-info/icons: some app-icons.tar.gz seem to carry
  too restrictive permissions.
* Sat Oct  4 2014 badshah400@gmail.com
- Add gnome-software-add-default-yast-appfolder.patch to add a
  YaST app-folder by default, in addition to existing app-folders
  Sundry and Utilities; fixes boo#897713.
* Sat Oct  4 2014 dimstar@opensuse.org
- Move %%lang_package before the definition of
  zypp-plugin-appstream to not confuse RPM with the redefined
  version of the subpackage.
* Sat Oct  4 2014 dimstar@opensuse.org
- Split InstallAppdata.sh in an own package libzypp-plugin-appdata:
  other software centers might have to rely on this as well in the
  future.
- Add appstream-glib Requires and minimum version for libzypp to
  libzypp-plugin-appdata.
* Thu Oct  2 2014 dimstar@opensuse.org
- Drop PackageKit-branding-upstream Requires: PK 1.0.0 got a major
  rework and dropped the DesktopFile database. So the 'openSUSE'
  branded package is good enough.
- Add InstallAppdata.sh: the script is executed by libzypp whenever
  some repos are refreshed. The script extracts the appstream data
  from the repo metadata and installs it into the 'well known'
  location on the file system (/usr/share/app-info).
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Bugfixes:
  - Fit better on 1024x768 screens.
  - Fix an issue that prevented closing the app folder dialog
    under certain circumstances.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + New Features: Use the new PackageKit 1.0.0 'Offline' interface
    to do offline updates.
  + Bugfixes:
  - Fix a number of crashes that stemmed from us incorrectly
    using the gtk+ API from worker threads.
  - Don't use thread unsafe g_main_context_find_source_by_id.
  - Avoid crashing on kind changes on "core" apps.
  - Fix a crash when going back from Details view after having
    installed an app.
  - Improve the Installed page to not show duplicate entries
    after having refreshed updates.
  - Fix the gnome-software UI not showing up after using
    gnome-shell search.
  - Don't show core packages like kernel and glibc under Add-ons.
  - Remove unused PackageKit runtime-updates and search plugins.
  - When searching returns addons, return the application they
    extend.
  - ... and a number of other crasher and correctness fixes for
    various corner cases.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + New Features: Support the new HighContrast kudo.
  + Bugfixes:
  - Avoid resizing tiles during initial front page load.
  - Improve the "Installed" label positioning on the front page
    tiles.
  - Do not use the GTK icon cache when loading AppStream icons.
  - Improve the category sidebar sizing.
  - Focus the search entry on keypress.
  - Make screenshot selection work again.
  - Reload pages in the software center when the updates cache is
    changed or when another tool touches the package database.
  - Improve robustness with the "Restart & Install" shutdown
    dialog.
  - Do not show QT versions of applications where a GTK version
    is available.
  - Remove the DesktopDB database plugin.
  - Fix compile for people using appstream-glib from git master.
  - Fix occasional search-as-you-type crash.
  - Do not create Epiphany webapps with double .desktop prefix.
  - Fix an issue that caused duplicate search results.
  - Sort by the search match value when displaying multiple apps.
  - Update hardcoded desktop file names after latest renames.
  - Allow translation of the 'and' and 'or' terms in the project
    license.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + New Features:
  - Add a few more non-gnome games to the random list.
  - Add HighContrast icons.
  - Implement getting popular apps from a specific category.
  - Show popular games as a separate section in the landing page.
  - Show the star ratings in more places.
  - Suggest applications if other apps from the same source
    package are installed.
  + Bugfixes:
  - Add icon directory to theme search path.
  - Avoid a visible redraw when switching to the updates page.
  - Change the recommended apps category each day.
  - Do not fail to start when there is no network.
  - Drop deprecated use of stock icons.
  - Drop the use of deprecated margin-left/right.
  - Fix displaying screenshots of fonts, which do not have
    predictable sizes.
  - Fix the details layout when a package has a long licence
    string.
  - Make the category view sidebar match the mockup more closely.
  - Move install button to a more prominent place.
  - Never reuse a GCancellable to prevent a crash.
  - Refresh the details page after remove confirmation dialog.
  - Show a different message when downloading updates.
  - Update help strings for command line arguments.
  - Use CSS for tile styling.
  - Use GQueue for the back entry.
  + Updated translations.
- Build HighContrast icon cache in post/postun.
- Bump gs_plugin_api to 6, following upstream.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + New Features:
  - New first run dialog.
  - Automatically suggest new application picks based on a
    heuristic.
  - Improved screenshot resizing / padding / sharpening.
  - New --prefer-local command line option to test local appdata
    files.
  + Bugfix:
  - Update hardcoded desktop filenames.
  - Port gnome-software core to use several libappstream-glib
    data structures directly instead of duplicating them.
  - Adapt for spinner sizing changes in GTK+.
  - Fix the build with clang.
  - Use a valid icon size for the stop button in the updates
    page.
  - Fix a small memory leak in the AppStream plugin.
  - Support new-style AppStream kudos.
  - Award a Kudo if an application has perfect screenshots.
  - Never show installed software in the 'Picks' section.
  - Only show applications in 'Other' that did not match any
    other subcategories.
  - Add more desktop file keywords.
  - Misc. spelling and wording fixes.
  + Updated translations.
- Introduce gs_plugin_api %%define, currently set to 4. Allow for
  easy change in line with configure.ac.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + New Features:
  - Support for application addons, available on app details
    page.
  - A new GSettings key that can be used for disabling automatic
    update downloads.
  - Added desktop file search keywords.
  + Bugfix:
  - Various fixes and improvements to update notifications.
  - Show system apps on the Installed page.
  - Improve the sorting order on the Installed page.
  - Show a placeholder when no update details are available.
  - update dialog: Show full version for updates.
  - Improve error handling for app install / removal.
  - Don't cancel the search when pressing enter too quickly.
  - Update theming for recent Adwaita changes.
  - Dogtail test suite fixes.
  - Do not log a warning when trying to parse MetaInfo files.
  - AppStream: Do not rely on X-Kudo-RecentRelease.
  - Some other minor bug fixes and internal restructuring.
- Changes from version 3.13.2:
  + New Features:
  - Implement search-as-you-type in the overview.
  - Make the project licenses hyperlinked to the SPDX site.
  - Move installed updates review to a dialog.
  - Support both old-style and new-style appdata files.
  + Bugfix:
  - Add Kalev to AUTHORS.
  - Add <project_license> to the AppData file.
  - app widget: Don't reserve space for buttons in the update
    viewing mode.
  - Break out common code for a list of updates in a separate
    class.
  - Depend on a new appstream-glib.
  - Don't show _Pending in the header.
  - Fix the formatting specifiers for the i386 build with newer
    GCCs.
  - GsApplication:
    . Cancel the cancellable on shutdown.
    . Don't stay running as a service when not asked to.
  - menu-spec: Fix translation of some categories.
  - Never put 'Complicated' in the license field.
  - Rename GsAppWidget to GsAppRow.
  - Replace deprecated gtk_widget_reparent use.
  - update dialog:
    . Draw a separator between listbox items.
    . Implement better back button state tracking.
    . Use a GtkStack instead of manually hiding widgets.
  - Use the AppData files in all of the datadirs.
- Changes from version 3.13.1:
  + New Features:
  - Add an extra star if the IBus component defines a symbol.
  - Add some more dogtail tests.
  - Load app-install data on Ubuntu systems.
  - Popular applications should imply a certain level of quality.
  - Port from GSimpleAsyncResult to GTask.
  - Port to using Appstream-Glib in the AppStream and AppData
    plugins.
  - Show an infobar with explanatory text for webapps.
  - Show the time we last checked for updates.
  - Update landing page 'Picks'.
  - Use a popover for the add folder subdialog.
  - Use package descriptions for applications on Ubuntu and
    Debian.
  + Bugfixes:
  - Add translation context in a number of places.
  - Always return valid results when using the shell search
    provider.
  - Always show the featured background gradient.
  - Bump minimum gtk+ version to 3.11.5.
  - Call g_set_prgname to set correct name for a11y tests.
  - Do not blacklist rpmfusion from the sources dialog.
  - Do not show 'Installed' on the app tile when actually
    installing.
  - Don't crash in the search provider for apps with missing
    icons.
  - Don't generate .service and .desktop file from config.status.
  - Fade in the loading spinner in the sources dialog.
  - Fix build with PackageKit < 0.9.1.
  - Fix showing recently installed updates.
  - Fix threadsafety issues with gtk icon theme use.
  - Grab focus to the entry in the app folder dialog.
  - Hide the screenshot widget when it cannot be loaded.
  - Improve display of recently installed updates.
  - Improve thread safety in the plugin loader.
  - Only show installed update notification once.
  - Only show non-empty folders in the shell.
  - Select newly created app folders.
  - Set an icon name for the main window.
  - Set the main window as the parent for error dialogs.
  - Show the repo name in the sources dialog.
  - Sort the results by kudo for the shell sort provider.
  - Update the last installed timestamp after successful offline
    updates.
  - Update URLs in the DOAP file.
  - Use a valid icon size for symbolic icons.
  - Use context to translate subcategory titles.
  + Updated translations.
- Add pkgconfig(appstream-glib) BuildRequires: new dependency.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Bug fixes:
  - Don't show _Pending in the header.
  - Fix the guint64 formatting specifiers.
  - Fix translation of some menu-spec categories.
  - Select newly created folders.
  + Updated translations.
* Sat Apr 12 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Bug fixes:
  - Always return valid results when using the shell search
    provider.
  - Always show the featured background gradient.
  - Disable the GTK pixel cache due to rendering artifacts.
  - Do not show 'Installed' on the app tile when actually
    installing.
  - Don't crash the search provider for apps with missing icons.
  - Drop unused libnotify dep.
  - GsApp: Notify property changes in an idle callback.
  - Hide the last checked label if we haven't yet checked for
    updates.
  - Improve thread safety in the plugin loader.
  - Only show installed update notification once.
  - Show the repo name in the sources dialog.
  - Sort the results by kudo for the shell sort provider.
  - Use a valid icon size for symbolic icons.
  - Use context to translate subcategory titles.
  + Updated translations.
- Drop pkgconfig(libnotify) BuildRequires: No longer needed.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Don't generate .service and .desktop file from config.status.
  + Always include glib-tap.mk.
  + Updated translations.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + New Features:
  - Use a popover for add folder subdialog.
  - Show time of last update check.
  - Add more tests.
  + Bug fixes:
  - Set parent for error dialogs.
  - Only show non-empty folders in the shell.
  - Fix crash with non-ASCII folder names.
  - Remove stale notifications.
  - Update last installed timestamp after offline updates.
  - Fix showing recently installed updates.
  - Improve display of recently installed updates.
  + Updated translations.
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: new dependency.
- Drop gnome-software-PK-released.patch: fixed upstream.
* Wed Mar  5 2014 dimstar@opensuse.org
- Do not apply gnome-software-PK-updates.patch: let's try the
  systemd offline update mechanism.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Add CSS for infobar theming.
  + Add support for the AppStream <languages> tag.
  + Add the concept of 'kudos' to an application.
  + Award a kudo if an application is available in the users
    language.
  + Award a kudo if an application is featured or recommended.
  + Award a kudo if an application ships an AppData screenshot.
  + Bugfixes:
  - Do not show local applications that do not have an icon
    specified
  - Do not use gtk_icon_theme_load_icon() as it's not thread
    safe.
  - Don't show missing history on a local package install.
  - Fade in the loading spinner.
  - Fix multiple bugs that caused the menu path not to be shown.
  - Improve tile layout in the category view.
  - Let the 'origin' span 3 columns.
  - Make use of the PackageKit summary in details when available.
  - Remove Settings category from the desktop file.
  - Remove the "Getting software details…" label.
  - Show the filename for local package installation.
  - Support the AppStream <project_license> tag.
  - Update software source message wording.
  - Use a per-list sort key when randomizing a list.
  - Use application/x-executable icon for local packages.
  - Use different icons for repo packages and addons.
  - Use new-style dialogs.
  - Warn when overwriting metadata keys that already exist.
  + Updated translations.
- Add gnome-software-PK-released.patch: Fix build with stable
  PackageKit releases.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + New Features:
  - Add 4 different infobars to show for local package types.
  - Add an initial version of the privacy policy for usage stats.
  - Load a core moduleset from a file.
  - Show some UI to remove external sources.
  - Show the installed application source in the details view.
  + Bugs fixed:
  - Add devassistant in the Development featured section.
  - Add missing mnemonics and accessible names.
  - Allow different distros to refine the list of hardcoded
    popular applications.
  - Allow specifying the optional text-shadow for the featured
    applications.
  - Automatically de-duplicate gs_app_add_related().
  - Do not show software sources in the updates panel.
  - Don't show such a big gap on the details page if there are no
    screenshots.
  - Load the GNOME moduleset from a file rather than hardcoding.
  - Promote packages found in the desktop-db to kind
    normal+desktop.
  - Specify text-shadow to improve legibility.
  - Set the application description for long single line package
    descriptions.
- Drop gnome-software-older-PK.patch: fixed upstream.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + New Features:
  - Add a concept of a rating confidence to each application.
  - Add a file handler to allow Software to install local
    packages.
  - Allow each plugin to define deps on other plugins.
  - Generate the 'Picks' on the overview automatically.
  - Show a star widget for each application in the category
    panel.
  - Some design updates for app folders.
  - Update to the latest designs that allow refreshing of the
    update lists.
  + Bugs fixed:
  - Add a plugin to optionally collect install/remove stats
    data.
  - Allow multiple plugins to set the name, summary and
    description.
  - Allow plugins to remove applications when resolving.
  - Create default app folders.
  - Fix a crash when using gs_app_subsume() in a thread.
  - Make the Transmission banner less critical.
  - Never show '[0]' in the installed panel tab.
  - Prepopulate Sundry and Utilities.
  - Respect category mapping with App folders.
  - Reunify launcher and service into one binary.
  - Selection mode improvements for 'Installed'.
  - Updated FSF's address.
  - Update to a new version of the tagger API to provide ratings
    confidence.
  + Updated translations.
- Add gnome-software-older-PK.patch: Fix build with PK < 0.9.1.
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + New Features:
  - Add Ardour to the featured list.
  - Add a --enable-dogtail configure switch.
  - Add a dep to gsettings-desktop-schemas.
  - Add a test for actions.
  - Add some work-in-progress UI tests.
  - Initial port of the PackageKit session interface.
  + Bugs fixed:
  - Add some accessible names to widgets.
  - Don't notify every hour for available updates.
  - Drop spinner for screenshot loading.
  - Ensure all calls to pkexec use g_child_watch_add().
  - Ensure that the application ratings are set correctly.
  - Fix the name of the offline update file.
  - Fix the speed regression by using the correct icon cache key.
  - Look up app folder names.
  - Make app folder configuration available.
  - Recognize if installed by jhbuild.
  - Show the 'Launch' button for installed web-apps too.
  - Some updates to the app folder dialog.
  - Update project homepage url.
  - Updates to the app widget layout.
  + Updated translations.
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + New Features:
  - More freatured apps.
  - Show the user-set ratings in a different color to system
    values.
  + Bugfix:
  - Be less alarming when notifying the user.
  - Class changed for searchbars.
  - Do not show empty 'blank' update descriptions.
  - Do not use the deprecated gtk_widget_set_margin_left.
  - Don't clear the offline update data early.
  - Fix a crasher in the screenshot loader.
  - Fix a potentially invalid read spotted by valgrind.
  - Fix automake warning about trailing whitespace.
  - Fix small issues in app-folder-dialog.ui.
  - Never show '0' as the updates counter.
  - Replace the firefox icon with a highres.
  - Return the error details in the GError if the offline update
    failed.
  - Show an error message if getting the historical update list
    failed.
  - Use a mnemonic in the details panel.
  - Use the system symbolic star icons.
  + Updated translations.
* Thu Nov 21 2013 mcatanzaro@gnome.org
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: new
  dependency.
- Handle schema installation using %%glib2_gsettings_schema_post/un.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + New Features:
  - Add a 'Launch' button to the application details page.
  - Add a dialog to edit app folders.
  - Add a selection mode to the installed list.
  - Download updates in the background.
  - Make links clickable in the ChangeLog descriptions.
  - Use proxy settings.
  + Bugfix:
  - Be a lot more subtle for the updates indicator.
  - Do not assert when the app goes from 'unavailable' to
    'available'.
  - Do not require exactly correct size screenshots.
  - Do not show a warning when there were no search results
    found.
  - Don't crash when there is no AppStream data.
  - Don't notify for available updates if we have a window
    active.
  - Don't show a modified date in 1970 for webapps.
  - Extract the correct language for preformatted AppStream.
  - Move the install and check timeouts to GSettings schema.
  - Never show two 'Addon' headers in the installed panel.
  - Only mark the stars as sensitive if the application is
    installed.
  - Parse the update descriptions as markdown.
  - Perform an 'AND' search when using keywords, not an 'OR'
    search.
  - Refresh the updates panel if the update state changes.
  - Reload the cache if AppStream files are changed.
  - Resolve the package when GetDetails() or GetUpdateDetail() is
    needed.
  - Set a minimum width for application details pages.
  - Show the featured application with the correct background.
  - Use GSettings for the compatible desktops.
  - Use a darker backdrop for screenshots.
  - Use a larger screenshot size when there is only one
    screenshot to show.
  - Use the new UTF-8 safe searching functionality in GLib.
  + Updated translations.
* Thu Oct 31 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + New Features:
  - Add a loading icon to empty tiles.
  - Add a module to submit the user rating to the fedora-tagger
    web service.
  - Add a plugin to read local installed AppData.
  - Add a search provider.
  - Add a test binary gnome-software-cmd which is useful for
    profiling.
  - Add profiling functionality that can show a boot-chart log of
    startup.
  - Add screenshots to each application if specified in the
    AppStream metadata.
  - Add support for 'missing' codecs that we know exist but we
    can't install.
  - Add support for epiphany web applications.
  - Add transitions to the screenshots.
  - Add update monitoring.
  - Allow an application to have multiple sources.
  - Allow search-by-mimetype in the UI.
  - Handle offline installation sensibly.
  - Support AppStream screenshot captions.
  - Support the Ubuntu extension 'X-AppInstall-Package' in
    desktop files.
  - Support the per-repo icon directories.
  - Turn gnome-software into a service.
  - Use GNotification.
  + Bugfixes:
  - Allow the AppStream metadata to enforce core applications.
  - Always show 'Remove' in the details panel for updatable
    applications.
  - Avoid clipped graphic in the featured banner.
  - Avoid reloading the overview more than once.
  - Correctly abort if PackageKit transactions fail.
  - Do not abort if the AppStream XML is invalid.
  - Do not crash if an icon is set to an empty string.
  - Do not crash if the AppData metadata does not have <pkgname>.
  - Do not crash if there is no /usr/share/appdata directory.
  - Do not crash when startup up without network access.
  - Do not fail to get the updates if getting the history fails.
  - Do not install plugins just used in 'make check'.
  - Do not load SVG icons when parsing desktop files to speed up
    startup.
  - Do not offer to 'Launch' addons like fonts and codecs.
  - Do not show insanely long licence strings.
  - Do not show local applications without icons, names or
    comments.
  - Do not use search using PackageKit by default.
  - Do not use the package icon when referring to software.
  - Don't emit a critical warning if there are no AppStream
    icons.
  - Don't emit notify::state from a thread.
  - Fix a critical error in gs_string_replace.
  - Fix a few small memory leaks.
  - Improve a11y on the details page.
  - Improve keynav on the search and details pages.
  - Improve the AppData file with more screenshots and a better
    description.
  - Make the screenshot error state prettier.
  - Match the AppStream ID when searching.
  - Monitor network status.
  - Never show the 'Remove' buttons in the update panel.
  - Notify about the correct application when installing from the
    details panel.
  - Only filter incompatible project groups when searching.
  - Prevent memory corruption when doing dedupe() more than once.
  - Remove the duplicate application with the lowest priority.
  - Remove the escape chars when unmunging the XML content.
  - Run the local ratings plugin before the hardcoded one.
  - Save the user rating if the user clicks the rating stars.
  - Set a cache age when using PackageKit.
  - Show 'Add-ons' in a seporate group on the installed shell.
  - Show a modal error message if install or remove actions
    failed.
  - Show a overlay of 'Updates' for updatable applications.
  - Show a star rating on the application details page.
  - Show font screenshots.
  - Show more detailed version numbers when required.
  - Show system applications at the end of the installed list.
  - Show the best locale when using AppData files for the
    description.
  - Show the package licence when available.
  - Show the screenshots in the application detail panel.
  - Sort the search results in a sane way.
  - Store all kinds of URL in the GsApp.
  - Support full markup in AppStream descriptions.
  - Use PackageKit if the licence or URL was not provided by
    AppStream.
  - Use a 96x96 icon if available on the details panel.
  - Use an API version when installing runtime loadable modules.
  - When de-duplicating packages preserve the updatable state.
  - When searching for codec names, use the keyword name.
  + Updated translations.
- Add pkgconfig(libsoup-2.4) BuildRequires: new dependency.
- Rebase gnome-software-PK-updates.patch.
* Fri Oct 18 2013 dimstar@opensuse.org
- Update to version 3.10.2:
  + Do not crash if the AppData metadata does not have <pkgname>.
  + Don't emit a critical warning if there are no AppStream icons.
  + Do not use the package icon when referring to software.
  + Set a cache age when using PackageKit.
* Mon Oct 14 2013 dimstar@opensuse.org
- Add gnome-software-PK-updates.patch: Use PackageKit for Software
  updates. GNOME Software defaults to use systemd offline updates,
  which we do not currently have enabled on openSUSE (bnc#842991).
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + This release only contains bugfixes from the 3.10.0 release and
    does not add new strings or new invasive features.
  + New Features:
  - Add a loading icon to empty tiles.
  - Mark IBus frameworks installed by default as system apps.
  - Remove the hardcoded ratings plugin.
  - Remove the hardcoded screenshot plugin.
  - Support the 'X-AppInstall-Package' extension in desktop
    files.
  - Support per-repo icon directories.
  - Use the new 16:9 screenshots.
  + Bugfixes:
  - Add back hover state to feature tile.
  - Always dedupe after refining results.
  - Always show 'Remove' for installed updatable applications.
  - Avoid reloading the overview more than once.
  - Do not abort if the AppStream XML is invalid.
  - Do not install plugins just used in 'make check'.
  - Do not remove the application widget twice when it changes
    state.
  - Do not show local applications without icons, names or
    comments.
  - Do not use the application state to modify how widgets are
    drawn.
  - Don't emit notify::state from a thread.
  - Fix a critical error in gs_string_replace().
  - Fix a few small memory leaks.
  - Fix a refcounting error that could cause a crash.
  - Mark strings in the AppData file as translatable.
  - Prevent memory corruption when doing dedupe() more than once.
  + Updated translations.
* Fri Sep 27 2013 dimstar@opensuse.org
- Add PackageKit-branding-upstream Requires: gnome-software
  requires ScanDesktopFiles=true in PK.conf, which openSUSE
  explicitly disables for performance reason. Users that want to
  test gnome-software (technical preview) will have to take this
  performance hit (bnc#842565).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + New Features:
  - Add a plugin to query the PackageKit prepared-update file
    directly.
  - Add hardcoded 'featured' subcategories.
  - Add installed overlay to app tiles.
  - Do not load incompatible projects when parsing AppStream
    data.
  + Bugfix:
  - Actually enforce squareness of popular tiles.
  - Add accessible relations in the overview page.
  - Add global shortcuts for the back button.
  - Add missing summary element to the AppStream data.
  - Avoid undue jumping in the overview page.
  - Deal gracefully with missing AppData.
  - Do not clear the offline-update trigger if rebooting
    succeeded.
  - Do not manually hide categories that have no results.
  - Do not show empty categories in the overview screen.
  - Don't explode when using metadata with 'type=font'.
  - Don't start the application if the command line arguments
    were wrong.
  - Fallback to .svg icon if .png is not found.
  - Fix up about dialog.
  - Give tiles a meaningful empty state.
  - Improve appearance of the update details list.
  - Improve keynav in category view.
  - Look sharp in HighContrast too.
  - Make feature strings wrap.
  - Make the size of featured categories accurate.
  - Never show 'Unknown' in the package history listbox.
  - Never show the 'Settings' category.
  - Padding tweaks in the overview.
  - Rename General to Other and sort it to the end.
  - Show the window right away.
  - Support AppStream metadata formats where the icon extension
    is not specified.
  - Translate the AppData file.
  + Updated translations.
* Sun Sep 15 2013 zaitor@opensuse.org
- Add suse-xsl-stylesheets and pkgconfig(libxslt) BuildRequires,
  needed in order to build man pages.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + New Features:
  - Add a better icon for 'no results found'.
  - Add a new application icon.
  - Add a packagekit-history plugin that sets history data on
    applications.
    Add a plugin to get a list of the processed offline updates.
  - Add featured data based on new mockups.
  - Add gs_app_to_string() for dumping all properties and
    metadata on a GsApp.
  - Add Settings and PackageManager as menu spec categories.
  - Add support for translations in AppStream.
  - Add the ability to see the history of a package.
  - Parse the keywords in the AppStream metadata.
  - Read data from featured.ini.
  + Bugfixes:
  - Add a dummy history item to applications with no history.
  - Add a way to force certain features.
  - Add gettext context for subcategory names.
  - Better dropshadow theme with active state.
  - Break out the lots of separate widgets.
  - Convert a few GsApp metadata items into properties and
    clarify the differences.
  - Do not decompress icons when first running gnome-software.
  - Do not include the Fedora AppStream data in the upstream
    tarball.
  - Do not show available packages when installed results are
    available when searching.
  - Don't override the state if already known.
  - Ensure the same app from two different plugins does not show
    more than once.
  - Fix a typo in a translatable string.
  - Fix up visiblity handling for header buttons.
  - Get names and comments for the correct locale in
    datadir-apps.
  - Ignore ENOENT reading the .desktop filename.
  - Improve category tiles and the category pages.
  - Load all AppStream files from /usr/share/app-info/xmls.
  - Make application details scroll.
  - Make debug env vars always available.
  - Make feature style code safe against reloading.
  - Make "installed badge" more legible.
  - Make subcategory list scrollable.
  - Make symbolic icons dim.
  - Never fail refine() if a single icon failed to load.
  - Notify when an app is installed.
  - Remove the hardcoded description plugin, it's all in the
    appdata markup now.
  - Search all datadirs at startup so that local builds can use
    the system AppStream data.
  - Search the appstream data for name, summary, description and
    keywords.
  - Set the app version in packagekit-refine if not already set.
  - Show app details from search in window.
  - Show a warning when new jhbuild users have no sample data.
  - Support AppStream data in /var/cache/app-info/xmls so support
    too.
  - Support the older gzip content type too.
  - Tweak punctuation for command line documentation.
  - Use 'File System' instead of 'Filesystem'.
  - When loading a specific mode at startup don't wait for the
    overview to load.
  + Updated translations.
- Add pkgconfig(gio-unix-2.0) and pkgconfig(libnotify)
  BuildRequires: new dependencies.
- Add icon_theme_cache and destop_database post/postun scripts.
* Fri Sep  6 2013 cfarrell@suse.com
- License update: GPL-2.0+
  Other than some files with GPL-3.0-with-autoconf-exception, no
  GPL-3.0 files found. Fedora also refers to the package as
  GPL-2.0+.
* Wed Sep  4 2013 dimstar@opensuse.org
- Initial package, version 3.9.2.
